<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Kidspress Pro
 * @since Kidspress Pro 1.0.0
 */

if ( ! function_exists( 'kidspress_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Kidspress Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function kidspress_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'kidspress_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'kidspress_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Kidspress Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function kidspress_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'kidspress_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'kidspress_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Kidspress Pro 1.0.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function kidspress_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'kidspress_pro_theme_options[pagination_enable]' )->value();
	}
endif;

/**
 * Front Page Active Callbacks
 */

/**
 * Check if topbar section is enabled.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_topbar_section_enable( $control ) {
	return ( $control->manager->get_setting( 'kidspress_pro_theme_options[topbar_section_enable]' )->value() );
}

/**
 * Check if slider section is enabled.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_slider_section_enable( $control ) {
	return ( $control->manager->get_setting( 'kidspress_pro_theme_options[slider_section_enable]' )->value() );
}

/**
 * Check if slider section content type is post.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_slider_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[slider_content_type]' )->value();
	return kidspress_pro_is_slider_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if slider section content type is testimonial.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_slider_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[slider_content_type]' )->value();
	return kidspress_pro_is_slider_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if slider section content type is category.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_slider_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[slider_content_type]' )->value();
	return kidspress_pro_is_slider_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if service section is enabled.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_service_section_enable( $control ) {
	return ( $control->manager->get_setting( 'kidspress_pro_theme_options[service_section_enable]' )->value() );
}

/**
 * Check if service section content type is post.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_service_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[service_content_type]' )->value();
	return kidspress_pro_is_service_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if service section seperator.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_service_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[service_content_type]' )->value();
	return kidspress_pro_is_service_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if service section content type is page.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_service_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[service_content_type]' )->value();
	return kidspress_pro_is_service_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if service section content type is category.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_service_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[service_content_type]' )->value();
	return kidspress_pro_is_service_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if course section is enabled.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_course_section_enable( $control ) {
	return ( $control->manager->get_setting( 'kidspress_pro_theme_options[course_section_enable]' )->value() );
}

/**
 * Check if course section content type is post.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_course_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[course_content_type]' )->value();
	return kidspress_pro_is_course_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if course section seperator.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_course_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[course_content_type]' )->value();
	return kidspress_pro_is_course_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if course section content type is page.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_course_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[course_content_type]' )->value();
	return kidspress_pro_is_course_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if course section content type is category.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_course_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[course_content_type]' )->value();
	return kidspress_pro_is_course_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if course section content type is page.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_course_section_content_course_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[course_content_type]' )->value();
	return kidspress_pro_is_course_section_enable( $control ) && ( 'course' == $content_type );
}

/**
 * Check if course section content type is page.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_course_section_content_course_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[course_content_type]' )->value();
	return kidspress_pro_is_course_section_enable( $control ) && ( 'course-category' == $content_type );
}

/**
 * Check if counter section is enabled.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_counter_section_enable( $control ) {
	return ( $control->manager->get_setting( 'kidspress_pro_theme_options[counter_section_enable]' )->value() );
}

/**
 * Check if teachers section is enabled.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_teachers_section_enable( $control ) {
	return ( $control->manager->get_setting( 'kidspress_pro_theme_options[teachers_section_enable]' )->value() );
}

/**
 * Check if teachers section content type is post.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_teachers_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[teachers_content_type]' )->value();
	return kidspress_pro_is_teachers_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if teachers section seperator.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_teachers_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[teachers_content_type]' )->value();
	return kidspress_pro_is_teachers_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if teachers section content type is page.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_teachers_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[teachers_content_type]' )->value();
	return kidspress_pro_is_teachers_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if teachers section content type is category.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_teachers_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[teachers_content_type]' )->value();
	return kidspress_pro_is_teachers_section_enable( $control ) && ( 'category' == $content_type );
}

////////////
/**
 * Check if teachers section content type is category.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_teachers_section_content_position_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[teachers_content_type]' )->value();
	return kidspress_pro_is_teachers_section_enable( $control ) && ( 'page' == $content_type || 'post' == $content_type || 'category' == $content_type );
}
//////////

/**
 * Check if teachers section content type is page.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_teachers_section_content_teachers_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[teachers_content_type]' )->value();
	return kidspress_pro_is_teachers_section_enable( $control ) && ( 'tp-team' == $content_type );
}

/**
 * Check if teachers section content type is page.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_teachers_section_content_teachers_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[teachers_content_type]' )->value();
	return kidspress_pro_is_teachers_section_enable( $control ) && ( 'tp-team-category' == $content_type );
}


/**
 * Check if gallery section is enabled.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_gallery_section_enable( $control ) {
	return ( $control->manager->get_setting( 'kidspress_pro_theme_options[gallery_section_enable]' )->value() );
}

/**
 * Check if gallery section content type is post.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_gallery_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[gallery_content_type]' )->value();
	return kidspress_pro_is_gallery_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if gallery section seperator.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_gallery_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[gallery_content_type]' )->value();
	return kidspress_pro_is_gallery_section_enable( $control ) && ( in_array( $content_type, array( 'page', 'post' ) ) );
}

/**
 * Check if gallery section content type is page.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_gallery_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[gallery_content_type]' )->value();
	return kidspress_pro_is_gallery_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if gallery section content type is category.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_gallery_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[gallery_content_type]' )->value();
	return kidspress_pro_is_gallery_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if subscription section is enabled.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_subscription_section_enable( $control ) {
	return ( $control->manager->get_setting( 'kidspress_pro_theme_options[subscription_section_enable]' )->value() );
}

/**
 * Check if about section is enabled.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_about_section_enable( $control ) {
	return ( $control->manager->get_setting( 'kidspress_pro_theme_options[about_section_enable]' )->value() );
}

/**
 * Check if about section content type is post.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_about_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[about_content_type]' )->value();
	return kidspress_pro_is_about_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if about section content type is page.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_about_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[about_content_type]' )->value();
	return kidspress_pro_is_about_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if about section content type is custom.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_about_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[about_content_type]' )->value();
	return kidspress_pro_is_about_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if blog section is enabled.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_blog_section_enable( $control ) {
	return ( $control->manager->get_setting( 'kidspress_pro_theme_options[blog_section_enable]' )->value() );
}

/**
 * Check if blog section content type is post.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_blog_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[blog_content_type]' )->value();
	return kidspress_pro_is_blog_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if blog section content type is page.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_blog_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[blog_content_type]' )->value();
	return kidspress_pro_is_blog_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if blog section content type is category.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_blog_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[blog_content_type]' )->value();
	return kidspress_pro_is_blog_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if blog section content type is recent.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_blog_section_content_recent_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[blog_content_type]' )->value();
	return kidspress_pro_is_blog_section_enable( $control ) && ( 'recent' == $content_type );
}

/**
 * Check if cta section is enabled.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_cta_section_enable( $control ) {
	return ( $control->manager->get_setting( 'kidspress_pro_theme_options[cta_section_enable]' )->value() );
}

/**
 * Check if cta section content type is post.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_cta_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[cta_content_type]' )->value();
	return kidspress_pro_is_cta_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if cta section content type is page.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_cta_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[cta_content_type]' )->value();
	return kidspress_pro_is_cta_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if cta section content type is custom.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_cta_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[cta_content_type]' )->value();
	return kidspress_pro_is_cta_section_enable( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if testimonial section is enabled.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_testimonial_section_modern( $control ) {
	return ( $control->manager->get_setting( 'kidspress_pro_theme_options[testimonial_section_modern]' )->value() );
}

/**
 * Check if testimonial section seperator.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_testimonial_section_content_seperator_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[testimonial_content_type]' )->value();
	return kidspress_pro_is_testimonial_section_modern( $control ) && ( 'category' !== $content_type );
}

/**
 * Check if testimonial section content type is post.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_testimonial_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[testimonial_content_type]' )->value();
	return kidspress_pro_is_testimonial_section_modern( $control ) && ( 'post' == $content_type );
}

/**
 * Check if testimonial section content type is page.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_testimonial_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[testimonial_content_type]' )->value();
	return kidspress_pro_is_testimonial_section_modern( $control ) && ( 'page' == $content_type );
}

/**
 * Check if testimonial section content type is category.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_testimonial_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[testimonial_content_type]' )->value();
	return kidspress_pro_is_testimonial_section_modern( $control ) && ( 'category' == $content_type );
}

/**
 * Check if testimonial section content type is position.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_testimonial_section_content_position_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[testimonial_content_type]' )->value();
	return kidspress_pro_is_testimonial_section_modern( $control ) && ( 'category' !== $content_type && 'tp-testimonial' !== $content_type );
}

/**
 * Check if testimonial section content type is custom.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_testimonial_section_content_custom_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[testimonial_content_type]' )->value();
	return kidspress_pro_is_testimonial_section_modern( $control ) && ( 'custom' == $content_type );
}

/**
 * Check if testimonial section content type is page.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_testimonial_section_content_testimonial_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[testimonial_content_type]' )->value();
	return kidspress_pro_is_testimonial_section_modern( $control ) && ( 'tp-testimonial' == $content_type  );
}

/*featured_posts section*/

/**
 * Check if featured_posts section is enabled.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_featured_posts_section_enable( $control ) {
	return ( $control->manager->get_setting( 'kidspress_pro_theme_options[featured_posts_section_enable]' )->value() );
}

/**
 * Check if featured_posts section content type is category.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_featured_posts_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[featured_posts_content_type]' )->value();
	return kidspress_pro_is_featured_posts_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if featured_posts section content type is page.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_featured_posts_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[featured_posts_content_type]' )->value();
	return kidspress_pro_is_featured_posts_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if featured_posts section content type is post.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_featured_posts_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[featured_posts_content_type]' )->value();
	return kidspress_pro_is_featured_posts_section_enable( $control ) && ( 'post' == $content_type );
}

/*end featured_posts section*/


/*popular_posts section*/

/**
 * Check if popular_posts section is enabled.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_popular_posts_section_enable( $control ) {
	return ( $control->manager->get_setting( 'kidspress_pro_theme_options[popular_posts_section_enable]' )->value() );
}

/**
 * Check if popular_posts section content type is category.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_popular_posts_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[popular_posts_content_type]' )->value();
	return kidspress_pro_is_popular_posts_section_enable( $control ) && ( 'category' == $content_type );
}

/**
 * Check if popular_posts section content type is page.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_popular_posts_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[popular_posts_content_type]' )->value();
	return kidspress_pro_is_popular_posts_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if popular_posts section content type is post.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_popular_posts_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[popular_posts_content_type]' )->value();
	return kidspress_pro_is_popular_posts_section_enable( $control ) && ( 'post' == $content_type );
}

/*end popular_posts section*/

/*recent section*/

function kidspress_pro_is_recent_section_enable( $control ) {
	return ( $control->manager->get_setting( 'kidspress_pro_theme_options[recent_section_enable]' )->value() );
}

function kidspress_pro_is_recent_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[recent_content_type]' )->value();
	return kidspress_pro_is_recent_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if recent section content type is page.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_recent_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[recent_content_type]' )->value();
	return kidspress_pro_is_recent_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if recent section content type is category.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_recent_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[recent_content_type]' )->value();
	return kidspress_pro_is_recent_section_enable( $control ) && ( 'category' == $content_type );
}

/*end recent section*/

/*sports_news section*/

function kidspress_pro_is_sports_news_section_enable( $control ) {
	return ( $control->manager->get_setting( 'kidspress_pro_theme_options[sports_news_section_enable]' )->value() );
}

function kidspress_pro_is_sports_news_section_content_post_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[sports_news_content_type]' )->value();
	return kidspress_pro_is_sports_news_section_enable( $control ) && ( 'post' == $content_type );
}

/**
 * Check if sports_news section content type is page.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_sports_news_section_content_page_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[sports_news_content_type]' )->value();
	return kidspress_pro_is_sports_news_section_enable( $control ) && ( 'page' == $content_type );
}

/**
 * Check if sports_news section content type is category.
 *
 * @since Kidspress Pro 1.0.0
 * @param WP_Customize_Control $control WP_Customize_Control instance.
 * @return bool Whether the control is active to the current preview.
 */
function kidspress_pro_is_sports_news_section_content_category_enable( $control ) {
	$content_type = $control->manager->get_setting( 'kidspress_pro_theme_options[sports_news_content_type]' )->value();
	return kidspress_pro_is_sports_news_section_enable( $control ) && ( 'category' == $content_type );
}

/*end sports_news section*/