<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage Kidspress Pro
 * @since Kidspress Pro 1.0.0
 * @return array An array of default values
 */

function kidspress_pro_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$kidspress_pro_default_options = array(
		// Color Options
		'header_title_color'			=> '#fff',
		'header_tagline_color'			=> '#fff',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#38AEF8',
		'secondary_colorscheme_hue'		=> '#f97755',
		'colorscheme'					=> 'default',
		'theme_version'					=> 'lite-version',
		'home_layout'					=> 'default-design',
		
		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',
		
		// loader
		'loader_enable'         		=> false,
		'loader_icon'         			=> 'default',

		// breadcrumb
		'breadcrumb_enable'				=> true,
		'breadcrumb_separator'			=> '/',
		
		// layout 
		'site_layout'         			=> 'wide',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> true,
		'menu_social_enable'			=> false,

		// excerpt options
		'long_excerpt_length'           => 25,
		'read_more_text'           		=> esc_html__( 'Read More', 'kidspress-pro' ),
		
		// pagination options
		'pagination_enable'         	=> true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s. ', '1: Year, 2: Site Title with home URL', 'kidspress-pro' ), '[the-year]', '[site-link]' ) . esc_html__( 'All Rights Reserved | ', 'kidspress-pro' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'kidspress-pro' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',
		'scroll_top_visible'        	=> true,

		// reset options
		'reset_options'      			=> false,
		
		// homepage options
		'enable_frontpage_content' 		=> false,

		// homepage sections sortable
		'sortable' 						=> 'slider,cta,service,course,about,blog,counter,teachers,gallery,testimonial,subscription',

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'kidspress-pro' ),
		'hide_date' 					=> false,
		'hide_category'					=> false,

		// single post theme options
		'single_post_hide_date' 		=> false,
		'single_post_hide_author'		=> false,
		'single_post_hide_category'		=> false,
		'single_post_hide_tags'			=> false,

		/* Front Page */

		// topbar
		'topbar_section_enable'			=> true,
		'topbar_social_enable'			=> false,
		'topbar_email'					=> esc_html__( 'contact@kiddoadmin.com', 'kidspress-pro' ),
		'topbar_phone'					=> esc_html__( '+0 00 000000000', 'kidspress-pro' ),

		// blog
		'slider_section_enable'			=> true,
		'slider_autoplay_enable'		=> false,
		'slider_content_type'			=> 'page',
		'slider_count'					=> 3,
		'slider_btn_title'				=> esc_html__( 'Learn More', 'kidspress-pro' ),
		'slider_alt_btn_title'			=> esc_html__( 'Contact Us', 'kidspress-pro' ),
		'slider_overlay_option'			=> 'content-overlay',

		// Call To Action
		'cta_section_enable'			=> true,
		'cta_content_type'				=> 'page',
		'cta_title'						=> esc_html__( 'We are happy to announce about the results of our student in secondary final examination...', 'kidspress-pro' ),
		'cta_btn_title'					=> esc_html__( 'Learn More', 'kidspress-pro' ),

		// service
		'service_section_enable'		=> true,
		'service_content_type'			=> 'category',
		'service_count'					=> 4,
		'service_column'				=> 'col-4',
		'service_sub_title'				=> esc_html__( 'Everything you need for a great year. Our Discovery Kindergarten kit comes with homeschooling curriculum and instructor guides designed to meet the needs of every learning style.', 'kidspress-pro' ),
		'service_title'					=> esc_html__( 'Learn As You Play', 'kidspress-pro' ),
		'service_btn_title'				=> esc_html__( 'View All Services', 'kidspress-pro' ),

		// course
		'course_section_enable'			=> true,
		'course_section_bg_image_enable' => true,
		'course_content_type'			=> 'category',
		'course_count'					=> 4,
		'course_column'					=> 'col-3',
		'course_title'					=> esc_html__( 'Playful Courses', 'kidspress-pro' ),
		'course_sub_title'				=> esc_html__( 'Everything you need for a great year. Our Discovery Kindergarten kit comes with homeschooling curriculum and instructor guides designed to meet the needs of every learning style.', 'kidspress-pro' ),
		'course_btn_title'				=> esc_html__( 'View All Courses', 'kidspress-pro' ),

		// About
		'about_section_enable'			=> true,
		'about_content_type'			=> 'page',
		'about_sub_title'				=> esc_html__( 'Tell Us Your Story&#33;', 'kidspress-pro' ),
		'about_title'					=> esc_html__( 'About Us', 'kidspress-pro' ),
		'about_description'				=> esc_html__( 'Minimalist architectural designers focus on the connection between two perfect planes, elegant lighting, and the void spaces left by the removal of three-dimensional shapes in an architectural design.', 'kidspress-pro' ),
		'about_btn_title'				=> esc_html__( 'Learn More', 'kidspress-pro' ),

		// blog
		'blog_section_enable'			=> true,
		'blog_section_bg_image_enable'	=> true,
		'blog_content_type'				=> 'recent',
		'blog_count'					=> 5,
		'blog_title'					=> esc_html__( 'Our School Life', 'kidspress-pro' ),
		'blog_sub_title'				=> esc_html__( 'Everything you need for a great year. Our Discovery Kindergarten kit comes with homeschooling curriculum and instructor guides designed to meet the needs of every learning style.', 'kidspress-pro' ),
		'blog_btn_title'				=> esc_html__( 'View All Blogs', 'kidspress-pro' ),

		// counter
		'counter_section_enable'		=> true,
		'counter_count'					=> 4,
		'counter_column'				=> 'col-4',
		'counter_sub_title'				=> esc_html__( 'Everything you need for a great year. Our Discovery Kindergarten kit comes with homeschooling curriculum and instructor guides designed to meet the needs of every learning style.', 'kidspress-pro' ),
		'counter_section_title'			=> esc_html__( 'Learn As You Play', 'kidspress-pro' ),

		// teachers
		'teachers_section_enable'			=> true,
		'teachers_section_bg_image_enable' 	=> true,
		'teachers_content_type'				=> 'category',
		'teachers_count'					=> 4,
		'teachers_column'					=> 'col-3',
		'teachers_title'					=> esc_html__( 'Meet Our Teachers', 'kidspress-pro' ),
		'teachers_sub_title'				=> esc_html__( 'Everything you need for a great year. Our Discovery Kindergarten kit comes with homeschooling curriculum and instructor guides designed to meet the needs of every learning style.', 'kidspress-pro' ),
		'teachers_btn_title'				=> esc_html__( 'View All Courses', 'kidspress-pro' ),

		// gallery
		'gallery_section_enable'		=> true,
		'gallery_content_type'			=> 'category',
		'gallery_count'					=> 4,
		'gallery_column'				=> 'col-2',
		'gallery_sub_title'				=> esc_html__( 'Everything you need for a great year. Our Discovery Kindergarten kit comes with homeschooling curriculum and instructor guides designed to meet the needs of every learning style.', 'kidspress-pro' ),
		'gallery_title'					=> esc_html__( 'Our Photo Gallery', 'kidspress-pro' ),
		'gallery_btn_title'				=> esc_html__( 'View All Gallery', 'kidspress-pro' ),

		// Featured
		'featured_section_enable'		=> true,
		'featured_sub_title'			=> esc_html__( 'Featured Gallery', 'kidspress-pro' ),
		'featured_title'				=> esc_html__( 'Capture Your Better World.', 'kidspress-pro' ),

		// testimonial
		'testimonial_section_modern'	=> true,
		'testimonial_section_bg_image_enable' => true,
		'testimonial_content_type'		=> 'category',
		'testimonial_count'				=> 3,

		// subscription
		'subscription_section_enable'	=> false,
		'subscription_sub_title'		=> esc_html__( 'Everything you need for a great year. Our Discovery Kindergarten kit comes with homeschooling curriculum and instructor guides designed to meet the needs of every learning style.', 'kidspress-pro' ),
		'subscription_title'			=> esc_html__( 'Subscribe Now', 'kidspress-pro' ),
		'subscription_btn_title'		=> esc_html__( 'Subscribe Now', 'kidspress-pro' ),

		// Featured Posts
		'featured_posts_section_enable'		=> true,
		'featured_posts_count'				=> 3,
		'featured_posts_content_type'		=> 'category',

		// popular Posts
		'popular_posts_section_enable'		=> true,
		'popular_title'						=> esc_html__( 'FEATURED STORY', 'kidspress-pro' ),
		'popular_posts_count'				=> 4,
		'popular_posts_content_type'		=> 'category',

		// recent
		'recent_section_enable'			=> true,
		'recent_title'					=> esc_html__( 'TWO COLUMN POSTS', 'kidspress-pro' ),
		'recent_content_type'			=> 'category',
		'recent_count'					=> 6,

		// sports_news
		'sports_news_section_enable'		=> true,
		'sports_news_title'					=> esc_html__( 'SPORTS NEWS', 'kidspress-pro' ),
		'sports_news_content_type'			=> 'category',
		'sports_news_count'					=> 4,

	);

	$output = apply_filters( 'kidspress_pro_default_theme_options', $kidspress_pro_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}