<?php
/**
 * Counter Section options
 *
 * @package Theme Palace
 * @subpackage Kidspress Pro
 * @since Kidspress Pro 1.0.0
 */

// Add Counter section
$wp_customize->add_section( 'kidspress_pro_counter_section', array(
	'title'             => esc_html__( 'Counters','kidspress-pro' ),
	'description'       => esc_html__( 'Counters Section options.', 'kidspress-pro' ),
	'panel'             => 'kidspress_pro_front_page_panel',
) );

// Counter content enable control and setting
$wp_customize->add_setting( 'kidspress_pro_theme_options[counter_section_enable]', array(
	'default'			=> 	$options['counter_section_enable'],
	'sanitize_callback' => 'kidspress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Kidspress_Pro_Switch_Control( $wp_customize, 'kidspress_pro_theme_options[counter_section_enable]', array(
	'label'             => esc_html__( 'Counter Section Enable', 'kidspress-pro' ),
	'section'           => 'kidspress_pro_counter_section',
	'on_off_label' 		=> kidspress_pro_switch_options(),
) ) );

if( $options['home_layout'] == 'default-design' || $options['home_layout'] == 'second-design' || $options['home_layout'] == 'third-design' ):

// counter title setting and control
$wp_customize->add_setting( 'kidspress_pro_theme_options[counter_section_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['counter_section_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'kidspress_pro_theme_options[counter_section_title]', array(
	'label'           	=> esc_html__( 'Title', 'kidspress-pro' ),
	'section'        	=> 'kidspress_pro_counter_section',
	'active_callback' 	=> 'kidspress_pro_is_counter_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'kidspress_pro_theme_options[counter_section_title]', array(
		'selector'            => '#counter .section-header h2',
		'settings'            => 'kidspress_pro_theme_options[counter_section_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'kidspress_pro_counter_title_partial',
    ) );
}

// counter sub title setting and control
$wp_customize->add_setting( 'kidspress_pro_theme_options[counter_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['counter_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'kidspress_pro_theme_options[counter_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'kidspress-pro' ),
	'section'        	=> 'kidspress_pro_counter_section',
	'active_callback' 	=> 'kidspress_pro_is_counter_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'kidspress_pro_theme_options[counter_sub_title]', array(
		'selector'            => '#counter .section-header p',
		'settings'            => 'kidspress_pro_theme_options[counter_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'kidspress_pro_counter_sub_title_partial',
    ) );
}
endif;

// counter content type control and setting
$wp_customize->add_setting( 'kidspress_pro_theme_options[counter_column]', array(
	'default'          	=> $options['counter_column'],
	'sanitize_callback' => 'kidspress_pro_sanitize_select',
) );

$wp_customize->add_control( 'kidspress_pro_theme_options[counter_column]', array(
	'label'             => esc_html__( 'Column Layout', 'kidspress-pro' ),
	'section'           => 'kidspress_pro_counter_section',
	'type'				=> 'select',
	'active_callback' 	=> 'kidspress_pro_is_counter_section_enable',
	'choices'			=> array( 
		'col-2'		=> esc_html__( 'Two Column', 'kidspress-pro' ),
		'col-3'		=> esc_html__( 'Three Column', 'kidspress-pro' ),
		'col-4'		=> esc_html__( 'Four Column', 'kidspress-pro' ),
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'kidspress_pro_theme_options[counter_count]', array(
	'default'          	=> $options['counter_count'],
	'sanitize_callback' => 'kidspress_pro_sanitize_number_range',
	'validate_callback' => 'kidspress_pro_validate_counter_count',
) );

$wp_customize->add_control( 'kidspress_pro_theme_options[counter_count]', array(
	'label'             => esc_html__( 'Number of Counters', 'kidspress-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'kidspress-pro' ),
	'section'           => 'kidspress_pro_counter_section',
	'active_callback'   => 'kidspress_pro_is_counter_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['counter_count']; $i++ ) :

	// counter note control and setting
	$wp_customize->add_setting( 'kidspress_pro_theme_options[counter_content_icon_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( new Kidspress_Pro_Icon_Picker( $wp_customize, 'kidspress_pro_theme_options[counter_content_icon_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Icon %d', 'kidspress-pro' ), $i ),
		'section'           => 'kidspress_pro_counter_section',
		'active_callback'	=> 'kidspress_pro_is_counter_section_enable',
	) ) );

	// counter title setting and control
	$wp_customize->add_setting( 'kidspress_pro_theme_options[counter_title_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'kidspress_pro_theme_options[counter_title_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Counter Title %d', 'kidspress-pro' ), $i ),
		'section'        	=> 'kidspress_pro_counter_section',
		'active_callback' 	=> 'kidspress_pro_is_counter_section_enable',
		'type'				=> 'text',
	) );

	// counter title setting and control
	$wp_customize->add_setting( 'kidspress_pro_theme_options[counter_number_' . $i . ']', array(
		'sanitize_callback' => 'absint',
	) );

	$wp_customize->add_control( 'kidspress_pro_theme_options[counter_number_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Counter Count %d', 'kidspress-pro' ), $i ),
		'section'        	=> 'kidspress_pro_counter_section',
		'active_callback' 	=> 'kidspress_pro_is_counter_section_enable',
		'type'				=> 'text',
	) );

	// counter hr setting and control
	$wp_customize->add_setting( 'kidspress_pro_theme_options[counter_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Kidspress_Pro_Customize_Horizontal_Line( $wp_customize, 'kidspress_pro_theme_options[counter_hr_'. $i .']',
		array(
			'section'         => 'kidspress_pro_counter_section',
			'active_callback' => 'kidspress_pro_is_counter_section_enable',
			'type'			  => 'hr'
	) ) );
endfor;



