<?php
/**
 * Call To Action Section options
 *
 * @package Theme Palace
 * @subpackage Kidspress Pro
 * @since Kidspress Pro 1.0.0
 */

// Add Call To Action section
$wp_customize->add_section( 'kidspress_pro_cta_section', array(
	'title'             => esc_html__( 'Call To Action','kidspress-pro' ),
	'description'       => esc_html__( 'Call To Action Section options.', 'kidspress-pro' ),
	'panel'             => 'kidspress_pro_front_page_panel',
) );

// Call To Action content enable control and setting
$wp_customize->add_setting( 'kidspress_pro_theme_options[cta_section_enable]', array(
	'default'			=> 	$options['cta_section_enable'],
	'sanitize_callback' => 'kidspress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Kidspress_Pro_Switch_Control( $wp_customize, 'kidspress_pro_theme_options[cta_section_enable]', array(
	'label'             => esc_html__( 'Call To Action Section Enable', 'kidspress-pro' ),
	'section'           => 'kidspress_pro_cta_section',
	'on_off_label' 		=> kidspress_pro_switch_options(),
) ) );

// Call To Action content type control and setting
$wp_customize->add_setting( 'kidspress_pro_theme_options[cta_content_type]', array(
	'default'          	=> $options['cta_content_type'],
	'sanitize_callback' => 'kidspress_pro_sanitize_select',
) );

$wp_customize->add_control( 'kidspress_pro_theme_options[cta_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'kidspress-pro' ),
	'section'           => 'kidspress_pro_cta_section',
	'type'				=> 'select',
	'active_callback' 	=> 'kidspress_pro_is_cta_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'kidspress-pro' ),
		'post' 		=> esc_html__( 'Post', 'kidspress-pro' ),
		'custom' 	=> esc_html__( 'Custom', 'kidspress-pro' ),
	),
) );

// cta pages drop down chooser control and setting
$wp_customize->add_setting( 'kidspress_pro_theme_options[cta_content_page]', array(
	'sanitize_callback' => 'kidspress_pro_sanitize_page',
) );

$wp_customize->add_control( new Kidspress_Pro_Dropdown_Chooser( $wp_customize, 'kidspress_pro_theme_options[cta_content_page]', array(
	'label'             => esc_html__( 'Select Page', 'kidspress-pro' ),
	'section'           => 'kidspress_pro_cta_section',
	'choices'			=> kidspress_pro_page_choices(),
	'active_callback'	=> 'kidspress_pro_is_cta_section_content_page_enable',
) ) );

// cta posts drop down chooser control and setting
$wp_customize->add_setting( 'kidspress_pro_theme_options[cta_content_post]', array(
	'sanitize_callback' => 'kidspress_pro_sanitize_page',
) );

$wp_customize->add_control( new Kidspress_Pro_Dropdown_Chooser( $wp_customize, 'kidspress_pro_theme_options[cta_content_post]', array(
	'label'             => esc_html__( 'Select Post', 'kidspress-pro' ),
	'section'           => 'kidspress_pro_cta_section',
	'choices'			=> kidspress_pro_post_choices(),
	'active_callback'	=> 'kidspress_pro_is_cta_section_content_post_enable',
) ) );

// cta title setting and control
$wp_customize->add_setting( 'kidspress_pro_theme_options[cta_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['cta_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'kidspress_pro_theme_options[cta_title]', array(
	'label'           	=> esc_html__( 'Title', 'kidspress-pro' ),
	'section'        	=> 'kidspress_pro_cta_section',
	'active_callback' 	=> 'kidspress_pro_is_cta_section_content_custom_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'kidspress_pro_theme_options[cta_title]', array(
		'selector'            => '#call-to-action .entry-header h2',
		'settings'            => 'kidspress_pro_theme_options[cta_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'kidspress_pro_cta_title_partial',
    ) );
}

// cta btn title setting and control
$wp_customize->add_setting( 'kidspress_pro_theme_options[cta_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['cta_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'kidspress_pro_theme_options[cta_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'kidspress-pro' ),
	'section'        	=> 'kidspress_pro_cta_section',
	'active_callback' 	=> 'kidspress_pro_is_cta_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'kidspress_pro_theme_options[cta_btn_title]', array(
		'selector'            => '#call-to-action a.btn',
		'settings'            => 'kidspress_pro_theme_options[cta_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'kidspress_pro_cta_btn_title_partial',
    ) );
}

// cta btn link setting and control
$wp_customize->add_setting( 'kidspress_pro_theme_options[cta_btn_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'kidspress_pro_theme_options[cta_btn_link]', array(
	'label'           	=> esc_html__( 'Button Link', 'kidspress-pro' ),
	'section'        	=> 'kidspress_pro_cta_section',
	'active_callback' 	=> 'kidspress_pro_is_cta_section_content_custom_enable',
	'type'				=> 'url',
) );
