<?php
/**
 * Featured Posts Section options
 *
 * @package Theme Palace
 * @subpackage Kidspress Pro
 * @since Kidspress Pro 1.0.0
 */

// Add Featured Posts section
$wp_customize->add_section( 'kidspress_pro_featured_posts_section', array(
	'title'             => esc_html__( 'Featured Posts','kidspress-pro' ),
	'description'       => esc_html__( 'Featured Posts Section options.', 'kidspress-pro' ),
	'panel'             => 'kidspress_pro_front_page_panel',
) );

// Featured Posts content enable control and setting
$wp_customize->add_setting( 'kidspress_pro_theme_options[featured_posts_section_enable]', array(
	'default'			=> 	$options['featured_posts_section_enable'],
	'sanitize_callback' => 'kidspress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Kidspress_Pro_Switch_Control( $wp_customize, 'kidspress_pro_theme_options[featured_posts_section_enable]', array(
	'label'             => esc_html__( 'Featured Posts Section Enable', 'kidspress-pro' ),
	'section'           => 'kidspress_pro_featured_posts_section',
	'on_off_label' 		=> kidspress_pro_switch_options(),
) ) );

// Event social icons number control and setting
$wp_customize->add_setting( 'kidspress_pro_theme_options[featured_posts_count]', array(
	'default'          	=> $options['featured_posts_count'],
	'sanitize_callback' => 'kidspress_pro_sanitize_number_range',
	'validate_callback' => 'kidspress_pro_validate_featured_posts_count',
) );

$wp_customize->add_control( 'kidspress_pro_theme_options[featured_posts_count]', array(
	'label'             => esc_html__( 'Number of Slides', 'kidspress-pro' ),
	'description'       => esc_html__( 'Note: Min 3 & Max 9. Please input the valid number and save. Then refresh the page to see the change.', 'kidspress-pro' ),
	'section'           => 'kidspress_pro_featured_posts_section',
	'active_callback'   => 'kidspress_pro_is_featured_posts_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 3,
		'max'	=> 9,
		'style' => 'width: 100px;'
		),
) );

// Featured Posts content type control and setting
$wp_customize->add_setting( 'kidspress_pro_theme_options[featured_posts_content_type]', array(
	'default'          	=> $options['featured_posts_content_type'],
	'sanitize_callback' => 'kidspress_pro_sanitize_select',
) );

$wp_customize->add_control( 'kidspress_pro_theme_options[featured_posts_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'kidspress-pro' ),
	'section'           => 'kidspress_pro_featured_posts_section',
	'type'				=> 'select',
	'active_callback' 	=> 'kidspress_pro_is_featured_posts_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'kidspress-pro' ),
		'post' 		=> esc_html__( 'Post', 'kidspress-pro' ),
		'category' 	=> esc_html__( 'Category', 'kidspress-pro' ),
	),
) );

for ( $i = 1; $i <= $options['featured_posts_count']; $i++ ) :
	// featured_posts pages drop down chooser control and setting
	$wp_customize->add_setting( 'kidspress_pro_theme_options[featured_posts_content_page_' . $i . ']', array(
		'sanitize_callback' => 'kidspress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Kidspress_Pro_Dropdown_Chooser( $wp_customize, 'kidspress_pro_theme_options[featured_posts_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'kidspress-pro' ), $i ),
		'section'           => 'kidspress_pro_featured_posts_section',
		'choices'			=> kidspress_pro_page_choices(),
		'active_callback'	=> 'kidspress_pro_is_featured_posts_section_content_page_enable',
	) ) );

	// featured_posts posts drop down chooser control and setting
	$wp_customize->add_setting( 'kidspress_pro_theme_options[featured_posts_content_post_' . $i . ']', array(
		'sanitize_callback' => 'kidspress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Kidspress_Pro_Dropdown_Chooser( $wp_customize, 'kidspress_pro_theme_options[featured_posts_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'kidspress-pro' ), $i ),
		'section'           => 'kidspress_pro_featured_posts_section',
		'choices'			=> kidspress_pro_post_choices(),
		'active_callback'	=> 'kidspress_pro_is_featured_posts_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'kidspress_pro_theme_options[featured_posts_content_category]', array(
	'sanitize_callback' => 'kidspress_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Kidspress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'kidspress_pro_theme_options[featured_posts_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'kidspress-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'kidspress-pro' ),
	'section'           => 'kidspress_pro_featured_posts_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'kidspress_pro_is_featured_posts_section_content_category_enable'
) ) );