<?php
/**
 * Gallery Section options
 *
 * @package Theme Palace
 * @subpackage Kidspress Pro
 * @since Kidspress Pro 1.0.0
 */

// Add Gallery section
$wp_customize->add_section( 'kidspress_pro_gallery_section', array(
	'title'             => esc_html__( 'Gallery','kidspress-pro' ),
	'description'       => esc_html__( 'Gallery Section options.', 'kidspress-pro' ),
	'panel'             => 'kidspress_pro_front_page_panel',
) );

// Gallery content enable control and setting
$wp_customize->add_setting( 'kidspress_pro_theme_options[gallery_section_enable]', array(
	'default'			=> 	$options['gallery_section_enable'],
	'sanitize_callback' => 'kidspress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Kidspress_Pro_Switch_Control( $wp_customize, 'kidspress_pro_theme_options[gallery_section_enable]', array(
	'label'             => esc_html__( 'Gallery Section Enable', 'kidspress-pro' ),
	'section'           => 'kidspress_pro_gallery_section',
	'on_off_label' 		=> kidspress_pro_switch_options(),
) ) );

// gallery title setting and control
$wp_customize->add_setting( 'kidspress_pro_theme_options[gallery_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['gallery_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'kidspress_pro_theme_options[gallery_title]', array(
	'label'           	=> esc_html__( 'Title', 'kidspress-pro' ),
	'section'        	=> 'kidspress_pro_gallery_section',
	'active_callback' 	=> 'kidspress_pro_is_gallery_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'kidspress_pro_theme_options[gallery_title]', array(
		'selector'            => '#gallery .section-header h2',
		'settings'            => 'kidspress_pro_theme_options[gallery_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'kidspress_pro_gallery_title_partial',
    ) );
}

if( $options['home_layout'] == 'default-design' || $options['home_layout'] == 'second-design' || $options['home_layout'] == 'third-design' ):
// gallery sub title setting and control
$wp_customize->add_setting( 'kidspress_pro_theme_options[gallery_sub_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['gallery_sub_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'kidspress_pro_theme_options[gallery_sub_title]', array(
	'label'           	=> esc_html__( 'Sub Title', 'kidspress-pro' ),
	'section'        	=> 'kidspress_pro_gallery_section',
	'active_callback' 	=> 'kidspress_pro_is_gallery_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'kidspress_pro_theme_options[gallery_sub_title]', array(
		'selector'            => '#gallery .section-header p ',
		'settings'            => 'kidspress_pro_theme_options[gallery_sub_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'kidspress_pro_gallery_sub_title_partial',
    ) );
}
endif;

// gallery content type control and setting
$wp_customize->add_setting( 'kidspress_pro_theme_options[gallery_column]', array(
	'default'          	=> $options['gallery_column'],
	'sanitize_callback' => 'kidspress_pro_sanitize_select',
) );

$wp_customize->add_control( 'kidspress_pro_theme_options[gallery_column]', array(
	'label'             => esc_html__( 'Column Layout', 'kidspress-pro' ),
	'section'           => 'kidspress_pro_gallery_section',
	'type'				=> 'select',
	'active_callback' 	=> 'kidspress_pro_is_gallery_section_enable',
	'choices'			=> array( 
		'col-2'		=> esc_html__( 'Two Column', 'kidspress-pro' ),
		'col-3'		=> esc_html__( 'Three Column', 'kidspress-pro' ),
		'col-4'		=> esc_html__( 'Four Column', 'kidspress-pro' ),
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'kidspress_pro_theme_options[gallery_count]', array(
	'default'          	=> $options['gallery_count'],
	'sanitize_callback' => 'kidspress_pro_sanitize_number_range',
	'validate_callback' => 'kidspress_pro_validate_gallery_count',
) );

$wp_customize->add_control( 'kidspress_pro_theme_options[gallery_count]', array(
	'label'             => esc_html__( 'Number of Gallery', 'kidspress-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'kidspress-pro' ),
	'section'           => 'kidspress_pro_gallery_section',
	'active_callback'   => 'kidspress_pro_is_gallery_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Gallery content type control and setting
$wp_customize->add_setting( 'kidspress_pro_theme_options[gallery_content_type]', array(
	'default'          	=> $options['gallery_content_type'],
	'sanitize_callback' => 'kidspress_pro_sanitize_select',
) );

$wp_customize->add_control( 'kidspress_pro_theme_options[gallery_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'kidspress-pro' ),
	'section'           => 'kidspress_pro_gallery_section',
	'type'				=> 'select',
	'active_callback' 	=> 'kidspress_pro_is_gallery_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'kidspress-pro' ),
		'post' 		=> esc_html__( 'Post', 'kidspress-pro' ),
		'category' 	=> esc_html__( 'Category', 'kidspress-pro' ),
	),
) );

for ( $i = 1; $i <= $options['gallery_count']; $i++ ) :

	// gallery pages drop down chooser control and setting
	$wp_customize->add_setting( 'kidspress_pro_theme_options[gallery_content_page_' . $i . ']', array(
		'sanitize_callback' => 'kidspress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Kidspress_Pro_Dropdown_Chooser( $wp_customize, 'kidspress_pro_theme_options[gallery_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'kidspress-pro' ), $i ),
		'section'           => 'kidspress_pro_gallery_section',
		'choices'			=> kidspress_pro_page_choices(),
		'active_callback'	=> 'kidspress_pro_is_gallery_section_content_page_enable',
	) ) );

	// gallery posts drop down chooser control and setting
	$wp_customize->add_setting( 'kidspress_pro_theme_options[gallery_content_post_' . $i . ']', array(
		'sanitize_callback' => 'kidspress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Kidspress_Pro_Dropdown_Chooser( $wp_customize, 'kidspress_pro_theme_options[gallery_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'kidspress-pro' ), $i ),
		'section'           => 'kidspress_pro_gallery_section',
		'choices'			=> kidspress_pro_post_choices(),
		'active_callback'	=> 'kidspress_pro_is_gallery_section_content_post_enable',
	) ) );

	// gallery hr setting and control
	$wp_customize->add_setting( 'kidspress_pro_theme_options[gallery_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Kidspress_Pro_Customize_Horizontal_Line( $wp_customize, 'kidspress_pro_theme_options[gallery_hr_'. $i .']',
		array(
			'section'         => 'kidspress_pro_gallery_section',
			'active_callback' => 'kidspress_pro_is_gallery_section_content_seperator_enable',
			'type'			  => 'hr'
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'kidspress_pro_theme_options[gallery_content_category]', array(
	'sanitize_callback' => 'kidspress_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Kidspress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'kidspress_pro_theme_options[gallery_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'kidspress-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'kidspress-pro' ),
	'section'           => 'kidspress_pro_gallery_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'kidspress_pro_is_gallery_section_content_category_enable'
) ) );

if ( $options['home_layout'] !== 'fourth-design' ):

// gallery btn title setting and control
$wp_customize->add_setting( 'kidspress_pro_theme_options[gallery_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['gallery_btn_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'kidspress_pro_theme_options[gallery_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'kidspress-pro' ),
	'section'        	=> 'kidspress_pro_gallery_section',
	'active_callback' 	=> 'kidspress_pro_is_gallery_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'kidspress_pro_theme_options[gallery_btn_title]', array(
		'selector'            => '#gallery .read-more a',
		'settings'            => 'kidspress_pro_theme_options[gallery_btn_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'kidspress_pro_gallery_btn_title_partial',
    ) );
}

// gallery btn link setting and control
$wp_customize->add_setting( 'kidspress_pro_theme_options[gallery_btn_link]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'kidspress_pro_theme_options[gallery_btn_link]', array(
	'label'           	=> esc_html__( 'Button Link', 'kidspress-pro' ),
	'section'        	=> 'kidspress_pro_gallery_section',
	'active_callback' 	=> 'kidspress_pro_is_gallery_section_enable',
	'type'				=> 'url',
) );

endif;