<?php
/**
 * Popular Posts Section options
 *
 * @package Theme Palace
 * @subpackage Kidspress Pro
 * @since Kidspress Pro 1.0.0
 */

// Add Popular Posts section
$wp_customize->add_section( 'kidspress_pro_popular_posts_section', array(
	'title'             => esc_html__( 'Popular Posts','kidspress-pro' ),
	'description'       => esc_html__( 'Popular Posts Section options.', 'kidspress-pro' ),
	'panel'             => 'kidspress_pro_front_page_panel',
) );

// Popular Posts content enable control and setting
$wp_customize->add_setting( 'kidspress_pro_theme_options[popular_posts_section_enable]', array(
	'default'			=> 	$options['popular_posts_section_enable'],
	'sanitize_callback' => 'kidspress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Kidspress_Pro_Switch_Control( $wp_customize, 'kidspress_pro_theme_options[popular_posts_section_enable]', array(
	'label'             => esc_html__( 'Popular Posts Section Enable', 'kidspress-pro' ),
	'section'           => 'kidspress_pro_popular_posts_section',
	'on_off_label' 		=> kidspress_pro_switch_options(),
) ) );

// popular title setting and control
$wp_customize->add_setting( 'kidspress_pro_theme_options[popular_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['popular_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'kidspress_pro_theme_options[popular_title]', array(
	'label'           	=> esc_html__( 'Title', 'kidspress-pro' ),
	'section'        	=> 'kidspress_pro_popular_posts_section',
	'active_callback' 	=> 'kidspress_pro_is_popular_posts_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'kidspress_pro_theme_options[popular_title]', array(
		'selector'            => '#magazine-popular-posts h2.section-title',
		'settings'            => 'kidspress_pro_theme_options[popular_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'kidspress_pro_popular_posts_title_partial',
    ) );
}

// Event social icons number control and setting
$wp_customize->add_setting( 'kidspress_pro_theme_options[popular_posts_count]', array(
	'default'          	=> $options['popular_posts_count'],
	'sanitize_callback' => 'kidspress_pro_sanitize_number_range',
	'validate_callback' => 'kidspress_pro_validate_popular_posts_count',
) );

$wp_customize->add_control( 'kidspress_pro_theme_options[popular_posts_count]', array(
	'label'             => esc_html__( 'Number of Slides', 'kidspress-pro' ),
	'description'       => esc_html__( 'Note: Min 4 & Max 10. Please input the valid number and save. Then refresh the page to see the change.', 'kidspress-pro' ),
	'section'           => 'kidspress_pro_popular_posts_section',
	'active_callback'   => 'kidspress_pro_is_popular_posts_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 4,
		'max'	=> 10,
		'style' => 'width: 100px;'
		),
) );

// Popular Posts content type control and setting
$wp_customize->add_setting( 'kidspress_pro_theme_options[popular_posts_content_type]', array(
	'default'          	=> $options['popular_posts_content_type'],
	'sanitize_callback' => 'kidspress_pro_sanitize_select',
) );

$wp_customize->add_control( 'kidspress_pro_theme_options[popular_posts_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'kidspress-pro' ),
	'section'           => 'kidspress_pro_popular_posts_section',
	'type'				=> 'select',
	'active_callback' 	=> 'kidspress_pro_is_popular_posts_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'kidspress-pro' ),
		'post' 		=> esc_html__( 'Post', 'kidspress-pro' ),
		'category' 	=> esc_html__( 'Category', 'kidspress-pro' ),
	),
) );

for ( $i = 1; $i <= $options['popular_posts_count']; $i++ ) :
	// popular_posts pages drop down chooser control and setting
	$wp_customize->add_setting( 'kidspress_pro_theme_options[popular_posts_content_page_' . $i . ']', array(
		'sanitize_callback' => 'kidspress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Kidspress_Pro_Dropdown_Chooser( $wp_customize, 'kidspress_pro_theme_options[popular_posts_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'kidspress-pro' ), $i ),
		'section'           => 'kidspress_pro_popular_posts_section',
		'choices'			=> kidspress_pro_page_choices(),
		'active_callback'	=> 'kidspress_pro_is_popular_posts_section_content_page_enable',
	) ) );

	// popular_posts posts drop down chooser control and setting
	$wp_customize->add_setting( 'kidspress_pro_theme_options[popular_posts_content_post_' . $i . ']', array(
		'sanitize_callback' => 'kidspress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Kidspress_Pro_Dropdown_Chooser( $wp_customize, 'kidspress_pro_theme_options[popular_posts_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'kidspress-pro' ), $i ),
		'section'           => 'kidspress_pro_popular_posts_section',
		'choices'			=> kidspress_pro_post_choices(),
		'active_callback'	=> 'kidspress_pro_is_popular_posts_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'kidspress_pro_theme_options[popular_posts_content_category]', array(
	'sanitize_callback' => 'kidspress_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Kidspress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'kidspress_pro_theme_options[popular_posts_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'kidspress-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'kidspress-pro' ),
	'section'           => 'kidspress_pro_popular_posts_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'kidspress_pro_is_popular_posts_section_content_category_enable'
) ) );