<?php
/**
 * Slider Section options
 *
 * @package Theme Palace
 * @subpackage Kidspress Pro
 * @since Kidspress Pro 1.0.0
 */

// Add Slider section
$wp_customize->add_section( 'kidspress_pro_slider_section', array(
	'title'             => esc_html__( 'Slider','kidspress-pro' ),
	'description'       => esc_html__( 'Slider Section options.', 'kidspress-pro' ),
	'panel'             => 'kidspress_pro_front_page_panel',
) );

// Slider content enable control and setting
$wp_customize->add_setting( 'kidspress_pro_theme_options[slider_section_enable]', array(
	'default'			=> 	$options['slider_section_enable'],
	'sanitize_callback' => 'kidspress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Kidspress_Pro_Switch_Control( $wp_customize, 'kidspress_pro_theme_options[slider_section_enable]', array(
	'label'             => esc_html__( 'Slider Section Enable', 'kidspress-pro' ),
	'section'           => 'kidspress_pro_slider_section',
	'on_off_label' 		=> kidspress_pro_switch_options(),
) ) );

// Slider content enable control and setting
$wp_customize->add_setting( 'kidspress_pro_theme_options[slider_autoplay_enable]', array(
	'default'			=> 	$options['slider_autoplay_enable'],
	'sanitize_callback' => 'kidspress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Kidspress_Pro_Switch_Control( $wp_customize, 'kidspress_pro_theme_options[slider_autoplay_enable]', array(
	'label'             => esc_html__( 'Slider Autoplay Enable', 'kidspress-pro' ),
	'section'           => 'kidspress_pro_slider_section',
	'on_off_label' 		=> kidspress_pro_switch_options(),
) ) );

$wp_customize->add_setting( 'kidspress_pro_theme_options[slider_overlay_option]', array(
		'default'           => $options['slider_overlay_option'],
		'sanitize_callback' => 'kidspress_pro_sanitize_select',
		'transport'			=> 'refresh'
	) );

$wp_customize->add_control( 'kidspress_pro_theme_options[slider_overlay_option]', array(
	'type'				=> 'radio',
	'label'             => esc_html__( 'Slider Overlay Option', 'kidspress-pro' ),
	'section'           => 'kidspress_pro_slider_section',
	'active_callback' 	=> 'kidspress_pro_is_slider_section_enable',
	'choices'				=> array( 
		'image-overlay'     => esc_html__( 'Overlay on Image', 'kidspress-pro' ),
		'content-overlay'     => esc_html__( 'Overlay on Text', 'kidspress-pro' ),
		)
) );



// Slider content type control and setting
$wp_customize->add_setting( 'kidspress_pro_theme_options[slider_content_type]', array(
	'default'          	=> $options['slider_content_type'],
	'sanitize_callback' => 'kidspress_pro_sanitize_select',
) );

$wp_customize->add_control( 'kidspress_pro_theme_options[slider_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'kidspress-pro' ),
	'section'           => 'kidspress_pro_slider_section',
	'type'				=> 'select',
	'active_callback' 	=> 'kidspress_pro_is_slider_section_enable',
	'choices'			=> array( 
		'page' 		=> esc_html__( 'Page', 'kidspress-pro' ),
		'post' 		=> esc_html__( 'Post', 'kidspress-pro' ),
		'category' 	=> esc_html__( 'Category', 'kidspress-pro' ),
	),
) );

// Event social icons number control and setting
$wp_customize->add_setting( 'kidspress_pro_theme_options[slider_count]', array(
	'default'          	=> $options['slider_count'],
	'sanitize_callback' => 'kidspress_pro_sanitize_number_range',
	'validate_callback' => 'kidspress_pro_validate_slider_count',
) );

$wp_customize->add_control( 'kidspress_pro_theme_options[slider_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'kidspress-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'kidspress-pro' ),
	'section'           => 'kidspress_pro_slider_section',
	'active_callback'   => 'kidspress_pro_is_slider_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['slider_count']; $i++ ) :
	// slider pages drop down chooser control and setting
	$wp_customize->add_setting( 'kidspress_pro_theme_options[slider_content_page_' . $i . ']', array(
		'sanitize_callback' => 'kidspress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Kidspress_Pro_Dropdown_Chooser( $wp_customize, 'kidspress_pro_theme_options[slider_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'kidspress-pro' ), $i ),
		'section'           => 'kidspress_pro_slider_section',
		'choices'			=> kidspress_pro_page_choices(),
		'active_callback'	=> 'kidspress_pro_is_slider_section_content_page_enable',
	) ) );

	// slider posts drop down chooser control and setting
	$wp_customize->add_setting( 'kidspress_pro_theme_options[slider_content_post_' . $i . ']', array(
		'sanitize_callback' => 'kidspress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Kidspress_Pro_Dropdown_Chooser( $wp_customize, 'kidspress_pro_theme_options[slider_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'kidspress-pro' ), $i ),
		'section'           => 'kidspress_pro_slider_section',
		'choices'			=> kidspress_pro_post_choices(),
		'active_callback'	=> 'kidspress_pro_is_slider_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'kidspress_pro_theme_options[slider_content_category]', array(
	'sanitize_callback' => 'kidspress_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Kidspress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'kidspress_pro_theme_options[slider_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'kidspress-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'kidspress-pro' ),
	'section'           => 'kidspress_pro_slider_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'kidspress_pro_is_slider_section_content_category_enable'
) ) );


// slider btn title setting and control
$wp_customize->add_setting( 'kidspress_pro_theme_options[slider_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['slider_btn_title'],
) );

$wp_customize->add_control( 'kidspress_pro_theme_options[slider_btn_title]', array(
	'label'           	=> esc_html__( 'Button Label', 'kidspress-pro' ),
	'section'        	=> 'kidspress_pro_slider_section',
	'active_callback' 	=> 'kidspress_pro_is_slider_section_enable',
	'type'				=> 'text',
) );

// slider btn title setting and control
$wp_customize->add_setting( 'kidspress_pro_theme_options[slider_alt_btn_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['slider_alt_btn_title'],
) );

$wp_customize->add_control( 'kidspress_pro_theme_options[slider_alt_btn_title]', array(
	'label'           	=> esc_html__( 'Alternative Button Label', 'kidspress-pro' ),
	'section'        	=> 'kidspress_pro_slider_section',
	'active_callback' 	=> 'kidspress_pro_is_slider_section_enable',
	'type'				=> 'text',
) );

// slider btn title setting and control
$wp_customize->add_setting( 'kidspress_pro_theme_options[slider_alt_btn_url]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'kidspress_pro_theme_options[slider_alt_btn_url]', array(
	'label'           	=> esc_html__( 'Alternative Button Url', 'kidspress-pro' ),
	'section'        	=> 'kidspress_pro_slider_section',
	'active_callback' 	=> 'kidspress_pro_is_slider_section_enable',
	'type'				=> 'url',
) );