<?php
/**
 * Testimonial Section options
 *
 * @package Theme Palace
 * @subpackage Kidspress Pro
 * @since Kidspress Pro 1.0.0
 */

// Add Testimonial section
$wp_customize->add_section( 'kidspress_pro_testimonial_section', array(
	'title'             => esc_html__( 'Testimonial','kidspress-pro' ),
	'description'       => esc_html__( 'Testimonial Section options.', 'kidspress-pro' ),
	'panel'             => 'kidspress_pro_front_page_panel',
) );

// Testimonial content enable control and setting
$wp_customize->add_setting( 'kidspress_pro_theme_options[testimonial_section_modern]', array(
	'default'			=> 	$options['testimonial_section_modern'],
	'sanitize_callback' => 'kidspress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Kidspress_Pro_Switch_Control( $wp_customize, 'kidspress_pro_theme_options[testimonial_section_modern]', array(
	'label'             => esc_html__( 'Testimonial Section Enable', 'kidspress-pro' ),
	'section'           => 'kidspress_pro_testimonial_section',
	'on_off_label' 		=> kidspress_pro_switch_options(),
) ) );

// Service content enable control and setting
$wp_customize->add_setting( 'kidspress_pro_theme_options[testimonial_section_bg_image_enable]', array(
	'default'			=> 	$options['testimonial_section_bg_image_enable'],
	'sanitize_callback' => 'kidspress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Kidspress_Pro_Switch_Control( $wp_customize, 'kidspress_pro_theme_options[testimonial_section_bg_image_enable]', array(
	'label'             => esc_html__( 'Enable Cloud Border', 'kidspress-pro' ),
	'section'           => 'kidspress_pro_testimonial_section',
	'active_callback'   => 'kidspress_pro_is_testimonial_section_modern',
	'on_off_label' 		=> kidspress_pro_switch_options(),
) ) );


// Event social icons number control and setting
$wp_customize->add_setting( 'kidspress_pro_theme_options[testimonial_count]', array(
	'default'          	=> $options['testimonial_count'],
	'sanitize_callback' => 'kidspress_pro_sanitize_number_range',
	'validate_callback' => 'kidspress_pro_validate_testimonial_count',
) );

$wp_customize->add_control( 'kidspress_pro_theme_options[testimonial_count]', array(
	'label'             => esc_html__( 'Number of Testimonials', 'kidspress-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'kidspress-pro' ),
	'section'           => 'kidspress_pro_testimonial_section',
	'active_callback'   => 'kidspress_pro_is_testimonial_section_modern',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 12,
		'style' => 'width: 100px;'
		),
) );

// Testimonial content type control and setting
$wp_customize->add_setting( 'kidspress_pro_theme_options[testimonial_content_type]', array(
	'default'          	=> $options['testimonial_content_type'],
	'sanitize_callback' => 'kidspress_pro_sanitize_select',
) );

$wp_customize->add_control( 'kidspress_pro_theme_options[testimonial_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'kidspress-pro' ),
	'section'           => 'kidspress_pro_testimonial_section',
	'type'				=> 'select',
	'active_callback' 	=> 'kidspress_pro_is_testimonial_section_modern',
	'choices'			=> kidspress_pro_testimonial_content_type(),
) );

// Add dropdown category setting and control.
$wp_customize->add_setting(  'kidspress_pro_theme_options[testimonial_content_category]', array(
	'sanitize_callback' => 'kidspress_pro_sanitize_single_category',
) ) ;

$wp_customize->add_control( new Kidspress_Pro_Dropdown_Taxonomies_Control( $wp_customize,'kidspress_pro_theme_options[testimonial_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'kidspress-pro' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'kidspress-pro' ),
	'section'           => 'kidspress_pro_testimonial_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'kidspress_pro_is_testimonial_section_content_category_enable'
) ) );

for ( $i = 1; $i <= $options['testimonial_count']; $i++ ) :
	// testimonial pages drop down chooser control and setting
	$wp_customize->add_setting( 'kidspress_pro_theme_options[testimonial_content_page_' . $i . ']', array(
		'sanitize_callback' => 'kidspress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Kidspress_Pro_Dropdown_Chooser( $wp_customize, 'kidspress_pro_theme_options[testimonial_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Testimonials %d', 'kidspress-pro' ), $i ),
		'section'           => 'kidspress_pro_testimonial_section',
		'choices'			=> kidspress_pro_page_choices(),
		'active_callback'	=> 'kidspress_pro_is_testimonial_section_content_page_enable',
	) ) );

	// testimonial pages drop down chooser control and setting
	$wp_customize->add_setting( 'kidspress_pro_theme_options[testimonial_content_testimonial_' . $i . ']', array(
		'sanitize_callback' => 'absint',
	) );

	$wp_customize->add_control( new Kidspress_Pro_Dropdown_Chooser( $wp_customize, 'kidspress_pro_theme_options[testimonial_content_testimonial_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Testimonial %d', 'kidspress-pro' ), $i ),
		'section'           => 'kidspress_pro_testimonial_section',
		'choices'			=> kidspress_pro_testimonial_choices(),
		'active_callback'	=> 'kidspress_pro_is_testimonial_section_content_testimonial_enable',
	) ) );

	// testimonial posts drop down chooser control and setting
	$wp_customize->add_setting( 'kidspress_pro_theme_options[testimonial_content_post_' . $i . ']', array(
		'sanitize_callback' => 'kidspress_pro_sanitize_page',
	) );

	$wp_customize->add_control( new Kidspress_Pro_Dropdown_Chooser( $wp_customize, 'kidspress_pro_theme_options[testimonial_content_post_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Post %d', 'kidspress-pro' ), $i ),
		'section'           => 'kidspress_pro_testimonial_section',
		'choices'			=> kidspress_pro_post_choices(),
		'active_callback'	=> 'kidspress_pro_is_testimonial_section_content_post_enable',
	) ) );

	// testimonial title setting and control
	$wp_customize->add_setting( 'kidspress_pro_theme_options[testimonial_title_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'kidspress_pro_theme_options[testimonial_title_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Title %d', 'kidspress-pro' ), $i ),
		'section'        	=> 'kidspress_pro_testimonial_section',
		'active_callback' 	=> 'kidspress_pro_is_testimonial_section_content_custom_enable',
		'type'				=> 'text',
	) );

	// testimonial position setting and control
	$wp_customize->add_setting( 'kidspress_pro_theme_options[testimonial_position_' . $i . ']', array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'kidspress_pro_theme_options[testimonial_position_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'position %d', 'kidspress-pro' ), $i ),
		'section'        	=> 'kidspress_pro_testimonial_section',
		'active_callback' 	=> 'kidspress_pro_is_testimonial_section_content_position_enable',
		'type'				=> 'text',
	) );

	// testimonial description setting and control
	$wp_customize->add_setting( 'kidspress_pro_theme_options[testimonial_description_' . $i . ']', array(
		'sanitize_callback' => 'wp_kses_post',
	) );

	$wp_customize->add_control( 'kidspress_pro_theme_options[testimonial_description_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Description %d', 'kidspress-pro' ), $i ),
		'section'        	=> 'kidspress_pro_testimonial_section',
		'active_callback' 	=> 'kidspress_pro_is_testimonial_section_content_custom_enable',
		'type'				=> 'textarea',
	) );

	// testimonial image setting and control.
	$wp_customize->add_setting( 'kidspress_pro_theme_options[testimonial_image_' . $i . ']', array(
		'sanitize_callback' => 'kidspress_pro_sanitize_image'
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'kidspress_pro_theme_options[testimonial_image_' . $i . ']',
			array(
			'label'       		=> sprintf( esc_html__( 'Image %d', 'kidspress-pro' ), $i ),
			'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'kidspress-pro' ), 200, 200 ),
			'section'     		=> 'kidspress_pro_testimonial_section',
			'active_callback'	=> 'kidspress_pro_is_testimonial_section_content_custom_enable',
	) ) );

	// testimonial position setting and control
	$wp_customize->add_setting( 'kidspress_pro_theme_options[testimonial_link_' . $i . ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'kidspress_pro_theme_options[testimonial_link_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'URL Link %d', 'kidspress-pro' ), $i ),
		'section'        	=> 'kidspress_pro_testimonial_section',
		'active_callback' 	=> 'kidspress_pro_is_testimonial_section_content_custom_enable',
		'type'				=> 'url',
	) );

	// testimonial hr setting and control
	$wp_customize->add_setting( 'kidspress_pro_theme_options[testimonial_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Kidspress_Pro_Customize_Horizontal_Line( $wp_customize, 'kidspress_pro_theme_options[testimonial_hr_'. $i .']',
		array(
			'section'         => 'kidspress_pro_testimonial_section',
			'active_callback' => 'kidspress_pro_is_testimonial_section_content_seperator_enable',
			'type'			  => 'hr'
	) ) );
endfor;


// testimonial btn title setting and control
$wp_customize->add_setting( 'educollege_pro_theme_options[testimonial_btn_url]', array(
	'sanitize_callback' => 'esc_url_raw',
) );

$wp_customize->add_control( 'educollege_pro_theme_options[testimonial_btn_url]', array(
	'label'           	=> esc_html__( 'Button Url', 'kidspress-pro' ),
	'section'        	=> 'educollege_pro_testimonial_section',
	'active_callback' 	=> 'educollege_pro_is_testimonial_section_enable',
	'type'				=> 'url',
) );

