<?php
/**
 * Topbar Section options
 *
 * @package Theme Palace
 * @subpackage Kidspress Pro
 * @since Kidspress Pro 1.0.0
 */

// Add Topbar section
$wp_customize->add_section( 'kidspress_pro_topbar_section', array(
	'title'             => esc_html__( 'Topbar','kidspress-pro' ),
	'description'       => esc_html__( 'Topbar Section options.', 'kidspress-pro' ),
	'panel'             => 'kidspress_pro_front_page_panel',
) );

// Topbar content enable control and setting
$wp_customize->add_setting( 'kidspress_pro_theme_options[topbar_section_enable]', array(
	'default'			=> 	$options['topbar_section_enable'],
	'sanitize_callback' => 'kidspress_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Kidspress_Pro_Switch_Control( $wp_customize, 'kidspress_pro_theme_options[topbar_section_enable]', array(
	'label'             => esc_html__( 'Topbar Section Enable', 'kidspress-pro' ),
	'section'           => 'kidspress_pro_topbar_section',
	'on_off_label' 		=> kidspress_pro_switch_options(),
) ) );

// top bar menu visible
$wp_customize->add_setting( 'kidspress_pro_theme_options[topbar_social_enable]',
	array(
		'default'       	=> $options['topbar_social_enable'],
		'sanitize_callback' => 'kidspress_pro_sanitize_switch_control',
	)
);
$wp_customize->add_control( new Kidspress_Pro_Switch_Control( $wp_customize, 'kidspress_pro_theme_options[topbar_social_enable]',
    array(
		'label'      		=> esc_html__( 'Display Social Menu', 'kidspress-pro' ),
		'description'       => sprintf( '%1$s <a class="topbar-menu-trigger" href="#"> %2$s </a> %3$s', esc_html__( 'Note: To show topbar menu.', 'kidspress-pro' ), esc_html__( 'Click Here', 'kidspress-pro' ), esc_html__( 'to create menu', 'kidspress-pro' ) ),
		'section'    		=> 'kidspress_pro_topbar_section',
		'active_callback'	=> 'kidspress_pro_is_topbar_section_enable',
		'on_off_label' 		=> kidspress_pro_switch_options(),
    )
) );

// topbar email setting and control
$wp_customize->add_setting( 'kidspress_pro_theme_options[topbar_email]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['topbar_email'],
) );

$wp_customize->add_control( new Kidspress_Pro_Multi_Input_Custom_Control( $wp_customize, 'kidspress_pro_theme_options[topbar_email]', array(
	'label'             => esc_html__( 'Email Address.', 'kidspress-pro' ),
	'button_text'       => esc_html__( 'Add Email Address', 'kidspress-pro' ),
	'section'           => 'kidspress_pro_topbar_section',
	'active_callback' 	=> 'kidspress_pro_is_topbar_section_enable',
) ) );


// topbar phone control and setting
$wp_customize->add_setting( 'kidspress_pro_theme_options[topbar_phone]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['topbar_phone'],
) );

$wp_customize->add_control( new Kidspress_Pro_Multi_Input_Custom_Control( $wp_customize, 'kidspress_pro_theme_options[topbar_phone]', array(
	'label'             => esc_html__( 'Phone No.', 'kidspress-pro' ),
	'button_text'       => esc_html__( 'Add Phone No.', 'kidspress-pro' ),
	'section'           => 'kidspress_pro_topbar_section',
	'active_callback' 	=> 'kidspress_pro_is_topbar_section_enable',
) ) );


if ( $options['home_layout'] == 'fourth-design' ):

$wp_customize->add_setting( 'kidspress_pro_theme_options[advertisement_image]', array(
	'sanitize_callback' => 'kidspress_pro_sanitize_image'
	) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'kidspress_pro_theme_options[advertisement_image]',
	array(
		'label'       		=> esc_html__( 'Ads Image', 'kidspress-pro' ),
		'description' 		=> sprintf( esc_html__( 'Recommended size: %1$dpx x %2$dpx ', 'kidspress-pro' ), 512, 520 ),
		'section'     		=> 'kidspress_pro_topbar_section',
		) ) );

// advertisement btn link setting and control
$wp_customize->add_setting( 'kidspress_pro_theme_options[advertisement_link]', array(
	'sanitize_callback' => 'esc_url_raw',
	) );

$wp_customize->add_control( 'kidspress_pro_theme_options[advertisement_link]', array(
	'label'           	=> esc_html__( 'Ads Link', 'kidspress-pro' ),
	'section'        	=> 'kidspress_pro_topbar_section',
	'type'				=> 'url',
	) );

endif;

