<?php
/**
 * Theme Palace options
 *
 * @package Theme Palace
 * @subpackage Kidspress Pro
 * @since Kidspress Pro 1.0.0
 */

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function kidspress_pro_page_choices() {
    $pages = get_pages();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'kidspress-pro' );
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = $page->post_title;
    }
    return  $choices;
}

/**
 * List of posts for post choices.
 * @return Array Array of post ids and name.
 */
function kidspress_pro_post_choices() {
    $posts = get_posts( array( 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'kidspress-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    wp_reset_postdata();
    return  $choices;
}

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function kidspress_pro_course_choices() {
    $courses = get_posts( array( 'numberposts' => -1, 'post_type'=>'tp-course' ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'kidspress-pro' );
    foreach ( $courses as $course ) {
        $choices[ $course->ID ] = $course->post_title;
    }
    wp_reset_postdata();
    return  $choices;
}

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function kidspress_pro_teachers_choices() {
    $teachers = get_posts( array( 'numberposts' => -1, 'post_type'=>'tp-team' ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'kidspress-pro' );
    foreach ( $teachers as $teacher ) {
        $choices[ $teacher->ID ] = $teacher->post_title;
    }
    wp_reset_postdata();
    return  $choices;
}

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function kidspress_pro_testimonial_choices() {
    $testimonials = get_posts( array( 'numberposts' => -1, 'post_type'=>'tp-testimonial' ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'kidspress-pro' );
    foreach ( $testimonials as $testimonial ) {
        $choices[ $testimonial->ID ] = $testimonial->post_title;
    }
    wp_reset_postdata();
    return  $choices;
}



if ( ! function_exists( 'kidspress_pro_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function kidspress_pro_typography_options(){
        $choices = array(
            'default'         => esc_html__( 'Default', 'kidspress-pro' ),
            'header-font-1'   => esc_html__( 'Rajdhani', 'kidspress-pro' ),
            'header-font-2'   => esc_html__( 'Cherry Swash', 'kidspress-pro' ),
            'header-font-3'   => esc_html__( 'Philosopher', 'kidspress-pro' ),
            'header-font-4'   => esc_html__( 'Slabo 27px', 'kidspress-pro' ),
            'header-font-5'   => esc_html__( 'Dosis', 'kidspress-pro' ),
        );

        $output = apply_filters( 'kidspress_pro_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;


if ( ! function_exists( 'kidspress_pro_body_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function kidspress_pro_body_typography_options(){
        $choices = array(
            'default'         => esc_html__( 'Default', 'kidspress-pro' ),
            'body-font-1'     => esc_html__( 'News Cycle', 'kidspress-pro' ),
            'body-font-2'     => esc_html__( 'Pontano Sans', 'kidspress-pro' ),
            'body-font-3'     => esc_html__( 'Gudea', 'kidspress-pro' ),
            'body-font-4'     => esc_html__( 'Quattrocento', 'kidspress-pro' ),
            'body-font-5'     => esc_html__( 'Khand', 'kidspress-pro' ),
        );

        $output = apply_filters( 'kidspress_pro_body_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;


if ( ! function_exists( 'kidspress_pro_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function kidspress_pro_site_layout() {
        $kidspress_pro_site_layout = array(
            'wide'  => get_template_directory_uri() . '/assets/images/full.png',
            'boxed-layout' => get_template_directory_uri() . '/assets/images/boxed.png',
            'frame-layout' => get_template_directory_uri() . '/assets/images/framed.png',
        );

        $output = apply_filters( 'kidspress_pro_site_layout', $kidspress_pro_site_layout );
        return $output;
    }
endif;

if ( ! function_exists( 'kidspress_pro_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function kidspress_pro_selected_sidebar() {
        $kidspress_pro_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'kidspress-pro' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar 1', 'kidspress-pro' ),
            'optional-sidebar-2'    => esc_html__( 'Optional Sidebar 2', 'kidspress-pro' ),
            'optional-sidebar-3'    => esc_html__( 'Optional Sidebar 3', 'kidspress-pro' ),
            'optional-sidebar-4'    => esc_html__( 'Optional Sidebar 4', 'kidspress-pro' ),
        );

        $output = apply_filters( 'kidspress_pro_selected_sidebar', $kidspress_pro_selected_sidebar );

        return $output;
    }
endif;


if ( ! function_exists( 'kidspress_pro_global_sidebar_position' ) ) :
    /**
     * Global Sidebar position
     * @return array Global Sidebar positions
     */
    function kidspress_pro_global_sidebar_position() {
        $kidspress_pro_global_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
        );

        $output = apply_filters( 'kidspress_pro_global_sidebar_position', $kidspress_pro_global_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'kidspress_pro_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function kidspress_pro_sidebar_position() {
        $kidspress_pro_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
            'no-sidebar-content'   => get_template_directory_uri() . '/assets/images/boxed.png',
        );

        $output = apply_filters( 'kidspress_pro_sidebar_position', $kidspress_pro_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'kidspress_pro_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function kidspress_pro_pagination_options() {
        $kidspress_pro_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'kidspress-pro' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'kidspress-pro' ),
            'infinite'  => esc_html__( 'Infinite', 'kidspress-pro' ),
        );

        $output = apply_filters( 'kidspress_pro_pagination_options', $kidspress_pro_pagination_options );

        return $output;
    }
endif;

if ( ! function_exists( 'kidspress_pro_get_spinner_list' ) ) :
    /**
     * List of spinner icons options.
     * @return array List of all spinner icon options.
     */
    function kidspress_pro_get_spinner_list() {
        $arr = array(
            'default'               => esc_html__( 'Default', 'kidspress-pro' ),
            'spinner-wheel'         => esc_html__( 'Wheel', 'kidspress-pro' ),
            'spinner-double-circle' => esc_html__( 'Double Circle', 'kidspress-pro' ),
            'spinner-two-way'       => esc_html__( 'Two Way', 'kidspress-pro' ),
            'spinner-umbrella'      => esc_html__( 'Umbrella', 'kidspress-pro' ),
            'spinner-dots'          => esc_html__( 'Dots', 'kidspress-pro' ),
            'spinner-one-way'       => esc_html__( 'One Way', 'kidspress-pro' ),
            'spinner-fidget'        => esc_html__( 'Fidget', 'kidspress-pro' ),
        );
        return apply_filters( 'kidspress_pro_spinner_list', $arr );
    }
endif;

if ( ! function_exists( 'kidspress_pro_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function kidspress_pro_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'kidspress-pro' ),
            'off'       => esc_html__( 'Disable', 'kidspress-pro' )
        );
        return apply_filters( 'kidspress_pro_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'kidspress_pro_hide_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function kidspress_pro_hide_options() {
        $arr = array(
            'on'        => esc_html__( 'Yes', 'kidspress-pro' ),
            'off'       => esc_html__( 'No', 'kidspress-pro' )
        );
        return apply_filters( 'kidspress_pro_hide_options', $arr );
    }
endif;

if ( ! function_exists( 'kidspress_pro_sortable_sections' ) ) :
    /**
     * List of sections Control options
     * @return array List of Sections control options.
     */
    function kidspress_pro_sortable_sections() {
        $sections = array(
            'slider'        => esc_html__( 'Slider', 'kidspress-pro' ),
            'cta'           => esc_html__( 'Call To Action', 'kidspress-pro' ),
            'service'       => esc_html__( 'Services', 'kidspress-pro' ),
            'course'        => esc_html__( 'Course', 'kidspress-pro' ),
            'about'         => esc_html__( 'About Us', 'kidspress-pro' ),
            'blog'          => esc_html__( 'Blog', 'kidspress-pro' ),
            'counter'       => esc_html__( 'Counter', 'kidspress-pro' ),
            'teachers'      => esc_html__( 'Teachers', 'kidspress-pro' ),
            'gallery'       => esc_html__( 'Gallery', 'kidspress-pro' ),
            'testimonial'   => esc_html__( 'Testimonial', 'kidspress-pro' ),
            'subscription'  => esc_html__( 'Subscription', 'kidspress-pro' ),
        );
        return apply_filters( 'kidspress_pro_sortable_sections', $sections );
    }
endif;

if ( ! function_exists( 'kidspress_pro_popular_course_content_type' ) ) :
    /**
     * Destination Options
     * @return array site gallery options
     */
    function kidspress_pro_popular_course_content_type() {
        $kidspress_pro_popular_course_content_type = array(
            'page'      => esc_html__( 'Page', 'kidspress-pro' ),
            'post'      => esc_html__( 'Post', 'kidspress-pro' ),
            'category'  => esc_html__( 'Category', 'kidspress-pro' ),
        );
        $custom_choices = array();
        if ( class_exists( 'TP_Education' ) ) {
            $custom_choices = array();
            if ( post_type_exists( 'tp-course' ) ) {
                $custom_choices['course'] = esc_html__('Course', 'kidspress-pro');
                $custom_choices['course-category']  = esc_html__( 'Course Category', 'kidspress-pro' );
            }
        }
        $kidspress_pro_popular_course_content_type = array_merge( $kidspress_pro_popular_course_content_type, $custom_choices );
        $output = apply_filters( 'kidspress_pro_popular_course_content_type', $kidspress_pro_popular_course_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'kidspress_pro_popular_teachers_content_type' ) ) :
    /**
     * Destination Options
     * @return array site gallery options
     */
    function kidspress_pro_popular_teachers_content_type() {
        $kidspress_pro_popular_teachers_content_type = array(
            'page'      => esc_html__( 'Page', 'kidspress-pro' ),
            'post'      => esc_html__( 'Post', 'kidspress-pro' ),
            'category'  => esc_html__( 'Category', 'kidspress-pro' ),
        );
        $custom_choices = array();
        if ( class_exists( 'TP_Education' ) ) {
            $custom_choices = array();
            if ( post_type_exists( 'tp-team' ) ) {
                $custom_choices['tp-team']  = esc_html__('Teachers', 'kidspress-pro');
                $custom_choices['tp-team-category']  = esc_html__('Teacher Category', 'kidspress-pro');
            }
        }
        $kidspress_pro_popular_teachers_content_type = array_merge( $kidspress_pro_popular_teachers_content_type, $custom_choices );
        $output = apply_filters( 'kidspress_pro_popular_teachers_content_type', $kidspress_pro_popular_teachers_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'kidspress_pro_testimonial_content_type' ) ) :
    /**
     * Destination Options
     * @return array site gallery options
     */
    function kidspress_pro_testimonial_content_type() {
        $kidspress_pro_testimonial_content_type = array(
            'page'      => esc_html__( 'Page', 'kidspress-pro' ),
            'post'      => esc_html__( 'Post', 'kidspress-pro' ),
            'custom'  => esc_html__( 'Custom', 'kidspress-pro' ),
            'category'  => esc_html__( 'Category', 'kidspress-pro' ),
        );
        $custom_choices = array();
        if ( class_exists( 'TP_Education' ) ) {
            $custom_choices = array();
            if ( post_type_exists( 'tp-testimonial' ) ) {
                $custom_choices['tp-testimonial'] = esc_html__( 'Testimonials', 'kidspress-pro' );
            }
        }
        $kidspress_pro_testimonial_content_type = array_merge( $kidspress_pro_testimonial_content_type, $custom_choices );
        $output = apply_filters( 'kidspress_pro_testimonial_content_type', $kidspress_pro_testimonial_content_type );


        return $output;
    }
endif;