<?php
/**
 * Blog section
 *
 * This is the template for the content of blog section
 *
 * @package Theme Palace
 * @subpackage Kidspress Pro
 * @since Kidspress Pro 1.0.0
 */
if ( ! function_exists( 'kidspress_pro_add_blog_section' ) ) :
    /**
    * Add blog section
    *
    *@since Kidspress Pro 1.0.0
    */
    function kidspress_pro_add_blog_section() {
    	$options = kidspress_pro_get_theme_options();
        // Check if blog is enabled on frontpage
        $blog_enable = apply_filters( 'kidspress_pro_section_status', true, 'blog_section_enable' );

        if ( true !== $blog_enable ) {
            return false;
        }
        // Get blog section details
        $section_details = array();
        $section_details = apply_filters( 'kidspress_pro_filter_blog_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render blog section now.
        kidspress_pro_render_blog_section( $section_details );
    }
endif;

if ( ! function_exists( 'kidspress_pro_get_blog_section_details' ) ) :
    /**
    * blog section details.
    *
    * @since Kidspress Pro 1.0.0
    * @param array $input blog section details.
    */
    function kidspress_pro_get_blog_section_details( $input ) {
        $options = kidspress_pro_get_theme_options();

        // Content type.
        $blog_content_type  = $options['blog_content_type'];
        $blog_count = ! empty( $options['blog_count'] ) ? $options['blog_count'] : 3;
        
        $content = array();
        switch ( $blog_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $blog_count; $i++ ) {
                    if ( ! empty( $options['blog_content_page_' . $i] ) )
                        $page_ids[] = $options['blog_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $blog_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $blog_count; $i++ ) {
                    if ( ! empty( $options['blog_content_post_' . $i] ) )
                        $post_ids[] = $options['blog_content_post_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $blog_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['blog_content_category'] ) ? $options['blog_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $blog_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'recent':
                $cat_ids = ! empty( $options['blog_category_exclude'] ) ? $options['blog_category_exclude'] : array();
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $blog_count ),
                    'category__not_in'  => ( array ) $cat_ids,
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['url']       = get_the_permalink();
                $page_post['excerpt']   = kidspress_pro_trim_content( 20 );
                $page_post['author']    = kidspress_pro_author();
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// blog section content details.
add_filter( 'kidspress_pro_filter_blog_section_details', 'kidspress_pro_get_blog_section_details' );


if ( ! function_exists( 'kidspress_pro_render_blog_section' ) ) :
  /**
   * Start blog section
   *
   * @return string blog content
   * @since Kidspress Pro 1.0.0
   *
   */
   function kidspress_pro_render_blog_section( $content_details = array() ) {
        $options = kidspress_pro_get_theme_options();
        $blog_content_type  = $options['blog_content_type'];

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <?php if ( $options['home_layout'] !== 'fourth-design' ): ?>
        <div id="latest-posts" class="relative page-section" style="background-image: url('<?php echo $options['blog_section_bg_image_enable'] ? esc_url(get_template_directory_uri() . '/assets/uploads/orange-cloud-2-bg.png') : ''; ?>')">
            <div class="wrapper">
                <?php if ( ! empty( $options['blog_title'] ) || ! empty( $options['blog_sub_title'] ) ) : ?>
                    <div class="section-header">
                    <?php if ( ! empty( $options['blog_title'] ) ) : ?>
                            <h2 class="section-title"><?php echo esc_html( $options['blog_title'] ); ?></h2>
                        <?php endif; 

                        if( $options['home_layout'] == 'default-design' || $options['home_layout'] == 'second-design' || $options['home_layout'] == 'third-design' ):

                        if ( ! empty( $options['blog_sub_title'] ) ) : ?>
                            <p class="section-subtitle"><?php echo esc_html( $options['blog_sub_title'] ); ?></p>
                        <?php 
                        endif;
                         endif; ?>
                    </div><!-- .section-header -->
                <?php endif; ?>

                <div class="section-content archive-blog-wrapper grid clear col-3">
                <?php foreach ( $content_details as $content ) : ?>
                    <article class="grid-item">
                        <div class="post-item-wrapper">
                            <?php if ( ! empty( $content['image'] ) ) : ?>
                                <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                                </div><!-- .featured-image -->
                            <?php endif; ?>

                            <div class="entry-container">
                                <div class="entry-meta">
                                    <?php if ( 'page' !== $blog_content_type ) : ?>
                                        <span class="cat-links">
                                            <?php the_category( '', '', $content['id'] ); ?>
                                        </span><!-- .cat-links -->
                                    <?php endif; ?>
                                </div><!-- .entry-meta -->

                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </header>

                                <div class="entry-content">
                                    <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                </div><!-- .entry-content -->
                            </div><!-- .entry-container -->
                        </div><!-- .post-item-wrapper -->
                    </article>
                <?php endforeach; ?>

                </div><!-- .section-content -->

                <?php if ( ! empty( $options['blog_btn_title'] ) && ! empty( $options['blog_btn_url'] ) ) : ?>
                    <div class="read-more">
                        <a href="<?php echo esc_url( $options['blog_btn_url'] ); ?>" class="btn">
                            <?php echo esc_html( $options['blog_btn_title'] ); ?>
                        </a>
                    </div><!-- .read-more -->
                <?php endif; ?>
            </div><!-- .wrapper -->
        </div><!-- #latest-posts -->
    <?php endif; ?>

    <?php if ( $options['home_layout'] == 'fourth-design' ): ?>

        <div id="magazine-most-viewed-posts" class="relative page-section">
            <div class="wrapper">
            <?php if( !empty( $options['blog_title'] ) ): ?>
                <div class="section-header">
                    <h2 class="section-title"><?php echo esc_html( $options['blog_title'] ); ?></h2>
                </div><!-- .section-header -->
            <?php endif; ?>

                <div class="section-content col-4 clear">

                    <?php foreach ( $content_details as $content ) : ?>

                    <article class="has-post-thumbnail">
                    <?php if ( ! empty( $content['image'] ) ) : ?>
                        <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                            <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                        </div><!-- .featured-image -->
                    <?php endif; ?>

                        <div class="entry-container">
                            <div class="entry-meta">
                                <?php if ( 'page' !== $blog_content_type ) : ?>
                                    <span class="cat-links">
                                        <?php the_category( '', '', $content['id'] ); ?>
                                    </span><!-- .cat-links -->
                                <?php endif; ?>                           
                            </div><!-- .entry-meta -->

                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                            </header>

                            <div class="entry-meta author-posted-on">
                                <?php
                                echo wp_kses_post( $content['author'] ); 

                                kidspress_pro_posted_on( $content['id'] );

                                ?>  
                            </div><!-- .entry-meta -->
                        </div><!-- .entry-container -->
                    </article>
                    
                <?php endforeach; ?>

                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div>

    <?php endif; ?>

    <?php }
endif;