<?php
/**
 * Counter section
 *
 * This is the template for the content of counter section
 *
 * @package Theme Palace
 * @subpackage Music Freak Pro
 * @since Music Freak Pro 1.0.0
 */
if ( ! function_exists( 'kidspress_pro_add_counter_section' ) ) :
    /**
    * Add counter section
    *
    *@since Music Freak Pro 1.0.0
    */
    function kidspress_pro_add_counter_section() {
        $options = kidspress_pro_get_theme_options();
        // Check if counter is enabled on frontpage
        $counter_enable = apply_filters( 'kidspress_pro_section_status', true, 'counter_section_enable' );

        if ( true !== $counter_enable ) {
            return false;
        }

        // Render counter section now.
        kidspress_pro_render_counter_section();
    }
endif;

if ( ! function_exists( 'kidspress_pro_render_counter_section' ) ) :
  /**
   * Start counter section
   *
   * @return string counter content
   * @since Music Freak Pro 1.0.0
   *
   */
   function kidspress_pro_render_counter_section() {
        $options = kidspress_pro_get_theme_options();
        $counter_count = ! empty( $options['counter_count'] ) ? $options['counter_count'] : 4;
        $column = !empty( $options['counter_column'] ) ? $options['counter_column'] : 'col-4' ;
        ?>

        <div id="counter" class="relative page-section same-background">
                <div class="wrapper">
                    <?php
                    if( $options['home_layout'] == 'default-design' || $options['home_layout'] == 'second-design' || $options['home_layout'] == 'third-design' ):
                     if ( ! empty( $options['counter_section_title'] ) || ! empty( $options['counter_sub_title'] ) ) : ?>
                        <div class="section-header">
                            <?php if ( ! empty( $options['counter_section_title'] ) ) : ?>
                                <h2 class="section-title"><?php echo esc_html( $options['counter_section_title'] ); ?></h2>
                            <?php endif; 

                            if ( ! empty( $options['counter_sub_title'] ) ) : ?>
                                <p class="section-subtitle"><?php echo esc_html( $options['counter_sub_title'] ); ?></p>
                            <?php endif; ?>

                        </div><!-- .section-header -->
                    <?php
                    endif;
                     endif; ?>

                    <div class="section-content clear col-4">
                        <?php for ( $i = 1; $i <= $counter_count; $i++ ) : ?>
                            <article>
                                <?php if ( ! empty( $options['counter_title_' . $i] ) && ! empty( $options['counter_number_' . $i] ) ) : ?>
                                    <div class="counter-item">
                                        <div class="icon-container">
                                            <i class="fa <?php echo ! empty( $options['counter_content_icon_' . $i] ) ? esc_attr( $options['counter_content_icon_' . $i] ) : 'fa-laptop' ?>"></i>
                                        </div><!-- .icon-container -->
                                        <span class="stat-count"><?php echo esc_html( $options['counter_number_' . $i] ); ?></span>
                                        <small><?php echo esc_html( $options['counter_title_' . $i] ); ?></small>
                                    </div><!-- .counter-item -->
                                <?php endif; ?>
                            </article>
                        <?php endfor; ?>
                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div><!-- #counter -->

    <?php }
endif;
