<?php
/**
 * Featured Posts section
 *
 * This is the template for the content of featured posts section
 *
 * @package Theme Palace
 * @subpackage Kidspress Pro
 * @since Kidspress Pro 1.0.0
 */
if ( ! function_exists( 'kidspress_pro_add_featured_posts_section' ) ) :
    /**
    * Add featured posts section
    *
    *@since Kidspress Pro 1.0.0
    */
    function kidspress_pro_add_featured_posts_section() {
    	$options = kidspress_pro_get_theme_options();
        // Check if featured posts is enabled on frontpage
        $featured_posts_enable = apply_filters( 'kidspress_pro_section_status', true, 'featured_posts_section_enable' );

        if ( true !== $featured_posts_enable ) {
            return false;
        }
        // Get featured posts section details
        $section_details = array();
        $section_details = apply_filters( 'kidspress_pro_filter_featured_posts_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render featured posts section now.
        kidspress_pro_render_featured_posts_section( $section_details );
    }
endif;

if ( ! function_exists( 'kidspress_pro_get_featured_posts_section_details' ) ) :
    /**
    * featured posts section details.
    *
    * @since Kidspress Pro 1.0.0
    * @param array $input featured posts section details.
    */
    function kidspress_pro_get_featured_posts_section_details( $input ) {
        $options = kidspress_pro_get_theme_options();

        // Content type.
        $featured_posts_content_type  = $options['featured_posts_content_type'];
        $featured_posts_count = ! empty( $options['featured_posts_count'] ) ? $options['featured_posts_count'] : 4;
        
        $content = array();
        switch ( $featured_posts_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $featured_posts_count; $i++ ) {
                    if ( ! empty( $options['featured_posts_content_page_' . $i] ) )
                        $page_ids[] = $options['featured_posts_content_page_' . $i];
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $featured_posts_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $featured_posts_count; $i++ ) {
                    if ( ! empty( $options['featured_posts_content_post_' . $i] ) )
                        $post_ids[] = $options['featured_posts_content_post_' . $i];
                }
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $featured_posts_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['featured_posts_content_category'] ) ? $options['featured_posts_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $featured_posts_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['author']    = kidspress_pro_author();
                    $page_post['excerpt']   = kidspress_pro_trim_content( 20 );
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';

                    // Push to the main array.
                    array_push( $content, $page_post );
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// featured posts section content details.
add_filter( 'kidspress_pro_filter_featured_posts_section_details', 'kidspress_pro_get_featured_posts_section_details' );


if ( ! function_exists( 'kidspress_pro_render_featured_posts_section' ) ) :
  /**
   * Start featured posts section
   *
   * @return string featured posts content
   * @since Kidspress Pro 1.0.0
   *
   */
   function kidspress_pro_render_featured_posts_section( $content_details = array() ) {
        $options = kidspress_pro_get_theme_options();
        $featured_posts_content_type  = $options['featured_posts_content_type'];

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="magazine-featured-posts" class="relative page-section">
            <div class="wrapper">
                <div class="section-content col-3 clear">

                <?php foreach ( $content_details as $content ) : ?>

                    <article>
                        <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                            <div class="entry-container">
                                <div class="entry-meta">
                                    <?php the_category( '', '', $content['id'] ); ?>                    
                                </div><!-- .entry-meta -->

                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </header>

                                <div class="entry-meta author-posted-on">
                                    <?php
                                    echo wp_kses_post( $content['author'] ); 

                                    kidspress_pro_posted_on( $content['id'] );

                                    ?>
                                </div><!-- .entry-meta -->  
                            </div><!-- .entry-container -->
                        </div><!-- .featured-image -->
                    </article>

                <?php endforeach; ?>
                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div>
        <?php
         }
endif;