<?php
/**
 * Service section
 *
 * This is the template for the content of gallery section
 *
 * @package Theme Palace
 * @subpackage Kidspress Pro
 * @since Kidspress Pro 1.0.0
 */
if ( ! function_exists( 'kidspress_pro_add_gallery_section' ) ) :
    /**
    * Add gallery section
    *
    *@since Kidspress Pro 1.0.0
    */
    function kidspress_pro_add_gallery_section() {
        $options = kidspress_pro_get_theme_options();
        // Check if gallery is enabled on frontpage
        $gallery_enable = apply_filters( 'kidspress_pro_section_status', true, 'gallery_section_enable' );

        if ( true !== $gallery_enable ) {
            return false;
        }
        // Get gallery section details
        $section_details = array();
        $section_details = apply_filters( 'kidspress_pro_filter_gallery_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render gallery section now.
        kidspress_pro_render_gallery_section( $section_details );
    }
endif;

if ( ! function_exists( 'kidspress_pro_get_gallery_section_details' ) ) :
    /**
    * gallery section details.
    *
    * @since Kidspress Pro 1.0.0
    * @param array $input gallery section details.
    */
    function kidspress_pro_get_gallery_section_details( $input ) {
        $options = kidspress_pro_get_theme_options();

        // Content type.
        $gallery_content_type  = $options['gallery_content_type'];
        $gallery_count = ! empty( $options['gallery_count'] ) ? $options['gallery_count'] : 4;
        
        $content = array();
        switch ( $gallery_content_type ) {
            
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $gallery_count; $i++ ) {
                    if ( ! empty( $options['gallery_content_page_' . $i] ) ) :
                        $page_ids[] = $options['gallery_content_page_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $gallery_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $gallery_count; $i++ ) {
                    if ( ! empty( $options['gallery_content_post_' . $i] ) ) :
                        $post_ids[] = $options['gallery_content_post_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $gallery_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['gallery_content_category'] ) ? $options['gallery_content_category'] : '';

                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $gallery_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                $i = 0;
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['id']        = get_the_id();
                    $page_post['auth_id']   = get_the_author_meta('ID');
                    $page_post['excerpt']   = kidspress_pro_trim_content( 30 );
                    $page_post['url']       = get_the_permalink();
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';
                    // Push to the main array.
                    array_push( $content, $page_post );
                    $i++;
                endwhile;
            endif;
            wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// gallery section content details.
add_filter( 'kidspress_pro_filter_gallery_section_details', 'kidspress_pro_get_gallery_section_details' );


if ( ! function_exists( 'kidspress_pro_render_gallery_section' ) ) :
  /**
   * Start gallery section
   *
   * @return string gallery content
   * @since Kidspress Pro 1.0.0
   *
   */
   function kidspress_pro_render_gallery_section( $content_details = array() ) {
        $options = kidspress_pro_get_theme_options();
        $column = ! empty( $options['gallery_column'] ) ? $options['gallery_column'] : 'col-4';
        $i = 1;        

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <?php if ( $options['home_layout'] !== 'fourth-design' ): ?>
        <div id="gallery" class="relative page-section same-background">
            <div class="wrapper">
                <?php if ( ! empty( $options['gallery_title'] ) || ! empty( $options['gallery_sub_title'] ) ) : ?>
                    <div class="section-header">
                        <?php if ( ! empty( $options['gallery_title'] ) ) : ?>
                            <h2 class="section-title"><?php echo esc_html( $options['gallery_title'] ); ?></h2>
                        <?php endif; 

                        if( $options['home_layout'] !== 'sixth-design' ):

                        if ( ! empty( $options['gallery_sub_title'] ) ) : ?>
                            <p class="section-subtitle"><?php echo esc_html( $options['gallery_sub_title'] ); ?></p>
                        <?php 
                        endif;
                        endif; ?>

                    </div><!-- .section-header -->
                <?php endif; ?>

                <!-- supports col-1, col-2, col-3, col-4 -->
                <div class="section-content gallery-popup clear <?php echo esc_attr( $options['gallery_column'] ) ; ?>">
                    <?php foreach ( $content_details as $content ) : ?>
                        <article>
                            <div class="gallery-item-wrapper">
                                <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');"></div>
                                <div class="gallery-overlay"><div class="overlay-bg"></div></div>
                                <div class="entry-container">
                                    <a href="<?php echo esc_url( $content['image'] ); ?>" class="popup"><i class="fa fa-search"></i></a>
                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                    </header>
                                </div>
                            </div><!-- .gallery-item-wrapper -->
                        </article>
                    <?php endforeach; ?>

                </div><!-- .section-content -->

                <?php if ( ! empty( $options['gallery_btn_title'] ) && ! empty( $options['gallery_btn_link'] ) ) : ?>
                    <div class="read-more">
                        <a href="<?php echo esc_url( $options['gallery_btn_link'] ); ?>" class="btn"><?php echo esc_html( $options['gallery_btn_title'] ); ?></a>
                    </div><!-- .read-more -->
                <?php endif; ?>
            </div><!-- .wrapper -->
        </div><!-- #gallery -->
    <?php endif; ?>

    <?php if ( $options['home_layout'] == 'fourth-design' ): ?>

        <div id="magazine-latest-posts" class="relative page-section">
            <div class="wrapper">
            <?php if( !empty( $options['gallery_title'] ) ): ?>
                <div class="section-header">
                    <h2 class="section-title"><?php echo esc_html( $options['gallery_title'] ); ?></h2>
                </div><!-- .section-header -->
            <?php endif; ?>

                <div class="section-content <?php echo esc_attr( $options['gallery_column'] ) ; ?> clear">
                    <?php foreach ( $content_details as $content ) : ?>

                    <article class="has-post-thumbnail">
                    <?php if( !empty( $content['image'] ) ): ?>
                        <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                            <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                        </div><!-- .featured-image -->
                    <?php endif; ?>

                        <div class="entry-container">
                            <div class="entry-meta">
                                <span class="cat-links">
                                    <?php the_category( '', '', $content['id'] ); ?>
                                </span>                            
                            </div><!-- .entry-meta -->

                            <header class="entry-header">
                                <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                            </header>

                            <div class="entry-meta author-posted-on">
                                <?php
                                echo kidspress_pro_author( $content['auth_id'] );

                                kidspress_pro_posted_on( $content['id'] );
                                ?>      
                            </div><!-- .entry-meta -->   

                            <div class="entry-content">
                                <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                            </div><!-- .entry-content -->
                        </div><!-- .entry-container -->
                    </article>

                <?php endforeach; ?>

                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div>

    <?php endif; ?>

    <?php }
endif;