<?php
/**
* Recent section
*
* This is the template for the content of featured_post section
*
* @package Theme Palace
* @subpackage Kidspress Pro
* @since Kidspress Pro 1.0.0
*/


$options = kidspress_pro_get_theme_options();

if( $options['recent_section_enable'] !== false ):

// Content type.
$recent_content_type  = $options['recent_content_type'];
$recent_count = ! empty( $options['recent_count'] ) ? $options['recent_count'] : 6;

$content_details = array();
switch ( $recent_content_type ) {

    case 'page':
    $page_ids = array();

    for ( $i = 1; $i <= $recent_count; $i++ ) {
        if ( ! empty( $options['recent_content_page_' . $i] ) )
            $page_ids[] = $options['recent_content_page_' . $i];
    }

    $args = array(
        'post_type'         => 'page',
        'post__in'          => ( array ) $page_ids,
        'posts_per_page'    => absint( $recent_count ),
        'orderby'           => 'post__in',
        );                    
    break;

    case 'post':
    $post_ids = array();

    for ( $i = 1; $i <= $recent_count; $i++ ) {
        if ( ! empty( $options['recent_content_post_' . $i] ) )
            $post_ids[] = $options['recent_content_post_' . $i];
    }
    $args = array(
        'post_type'         => 'post',
        'post__in'          => ( array ) $post_ids,
        'posts_per_page'    => absint( $recent_count ),
        'orderby'           => 'post__in',
        'ignore_sticky_posts'   => true,
        );                    
    break;

    case 'category':
    $cat_ids = ! empty( $options['recent_content_category'] ) ? $options['recent_content_category'] : '';
    $args = array(
        'post_type'         => 'post',
        'posts_per_page'    => absint( $recent_count ),
        'cat'               => absint( $cat_ids ),
        'ignore_sticky_posts'   => true,
        );                    
    break;

    default:
    break;
}


// Run The Loop.
$query = new WP_Query( $args );
if ( $query->have_posts() ) : 
    while ( $query->have_posts() ) : $query->the_post();
        $page_post['id']        = get_the_id();
        $page_post['auth_id']   = get_the_author_meta('ID');
        $page_post['title']     = get_the_title();
        $page_post['url']       = get_the_permalink();
        $page_post['excerpt']   = kidspress_pro_trim_content( 40 );
        $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-590x650.jpg';
        // Push to the main array.
        array_push( $content_details, $page_post );
    endwhile;
endif;
wp_reset_postdata();
?>

<div id="magazine-recent-posts" class="relative page-section">
<?php if( !empty( $options['recent_title'] ) ): ?>
    <div class="section-header">
        <h2 class="section-title"><?php echo esc_html( $options['recent_title'] ); ?></h2>
    </div><!-- .section-header -->
<?php endif; ?>

    <div class="section-content clear">

    <?php foreach ( $content_details as $content ) : ?>

        <article class="has-post-thumbnail">
            <div class="recent-post-item">
            <?php if( !empty( $content['image'] ) && !empty( $content['url'] ) ): ?>
                <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                    <a href="<?php echo esc_url( $content['url'] ); ?>" class="post-thumbnail-link"></a>
                </div><!-- .featured-image -->
            <?php endif; ?>

                <div class="entry-container">
                <?php if ( $recent_content_type !== 'page' ) : ?>
                    <div class="entry-meta">
                        <span class="cat-links">
                            <?php the_category( '', '', $content['id'] ); ?>
                        </span>                            
                    </div><!-- .entry-meta -->
                <?php endif; ?>

                    <header class="entry-header">
                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                    </header>

                    <div class="entry-meta author-posted-on">
                        <?php
                        echo kidspress_pro_author( $content['auth_id'] );

                        kidspress_pro_posted_on( $content['id'] );
                        ?>    
                    </div><!-- .entry-meta -->   

                    <div class="entry-content">
                        <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                    </div><!-- .entry-content -->
                </div><!-- .entry-container -->
            </div><!-- .recent-post-item -->
        </article>

    <?php endforeach; ?>

    </div><!-- .section-content -->
</div><!-- #magazine-recent-posts -->
<?php if( !empty( $options['ads_link'] ) && !empty( $options['ads_image'] ) ): ?>
    <div id="magazine-advertisement-section" class="relative page-section">
        <a href="<?php echo esc_url( $options['ads_link'] ); ?>"><img src="<?php echo esc_url( $options['ads_image'] ); ?>" alt="<?php esc_attr_e( 'site-advertisement', 'kidspress-pro' ); ?>"></a>
    </div><!-- .magazine-advertisement-section -->
<?php endif; ?>

<?php endif; ?>



