<?php
/**
 * Service section
 *
 * This is the template for the content of service section
 *
 * @package Theme Palace
 * @subpackage Kidspress Pro
 * @since Kidspress Pro 1.0.0
 */
if ( ! function_exists( 'kidspress_pro_add_service_section' ) ) :
    /**
    * Add service section
    *
    *@since Kidspress Pro 1.0.0
    */
    function kidspress_pro_add_service_section() {
    	$options = kidspress_pro_get_theme_options();
        // Check if service is enabled on frontpage
        $service_enable = apply_filters( 'kidspress_pro_section_status', true, 'service_section_enable' );

        if ( true !== $service_enable ) {
            return false;
        }
        // Get service section details
        $section_details = array();
        $section_details = apply_filters( 'kidspress_pro_filter_service_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render service section now.
        kidspress_pro_render_service_section( $section_details );
    }
endif;

if ( ! function_exists( 'kidspress_pro_get_service_section_details' ) ) :
    /**
    * service section details.
    *
    * @since Kidspress Pro 1.0.0
    * @param array $input service section details.
    */
    function kidspress_pro_get_service_section_details( $input ) {
        $options = kidspress_pro_get_theme_options();

        // Content type.
        $service_content_type  = $options['service_content_type'];
        $service_count = ! empty( $options['service_count'] ) ? $options['service_count'] : 4;
        
        $content = array();
        switch ( $service_content_type ) {
        	
            case 'page':
                $page_ids = array();
                $icons = array();

                for ( $i = 1; $i <= $service_count; $i++ ) {
                    if ( ! empty( $options['service_content_page_' . $i] ) ) :
                        $page_ids[] = $options['service_content_page_' . $i];
                        $icons[] = ! empty( $options['service_content_icon_' . $i] ) ? $options['service_content_icon_' . $i] : 'fa-cogs';
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $service_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();
                $icons = array();

                for ( $i = 1; $i <= $service_count; $i++ ) {
                    if ( ! empty( $options['service_content_post_' . $i] ) ) :
                        $post_ids[] = $options['service_content_post_' . $i];
                        $icons[] = ! empty( $options['service_content_icon_' . $i] ) ? $options['service_content_icon_' . $i] : 'fa-cogs';
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $service_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['service_content_category'] ) ? $options['service_content_category'] : '';
                $icons = array();
                
                for ( $i = 1; $i <= $service_count; $i++ ) {
                    $icons[] = ! empty( $options['service_content_icon_' . $i] ) ? $options['service_content_icon_' . $i] : 'fa-cogs';
                }

                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $service_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            default:
            break;
        }

            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                $i = 0;
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['icon']      = ! empty( $icons[ $i ] ) ? $icons[ $i ] : 'fa-cogs';
                    $page_post['excerpt']   = kidspress_pro_trim_content( 20 );

                    // Push to the main array.
                    array_push( $content, $page_post );
                    $i++;
                endwhile;
            endif;
            wp_reset_postdata();
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// service section content details.
add_filter( 'kidspress_pro_filter_service_section_details', 'kidspress_pro_get_service_section_details' );


if ( ! function_exists( 'kidspress_pro_render_service_section' ) ) :
  /**
   * Start service section
   *
   * @return string service content
   * @since Kidspress Pro 1.0.0
   *
   */
   function kidspress_pro_render_service_section( $content_details = array() ) {
        $options = kidspress_pro_get_theme_options();
        $column = ! empty( $options['service_column'] ) ? $options['service_column'] : 'col-4';      

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="our-services" class="relative page-section same-background">
            <div class="wrapper">
                <?php 
                if( $options['home_layout'] == 'default-design' || $options['home_layout'] == 'second-design' || $options['home_layout'] == 'third-design' ):

                if ( ! empty( $options['service_title'] ) || ! empty( $options['service_sub_title'] ) ) : ?>
                    <div class="section-header">
                        <?php if ( ! empty( $options['service_title'] ) ) : ?>
                            <h2 class="section-title"><?php echo esc_html( $options['service_title'] ); ?></h2>
                        <?php endif; 

                        if ( ! empty( $options['service_sub_title'] ) ) : ?>
                            <p class="section-subtitle"><?php echo esc_html( $options['service_sub_title'] ); ?></p>
                        <?php endif; ?>

                    </div><!-- .section-header -->
                <?php

                endif;

                endif; ?>

                <div class="section-content clear <?php echo esc_attr($column); ?>">
                    <?php foreach ( $content_details as $content ) : ?>
                        <article>
                            <div class="service-item-wrapper">
                                <div class="icon-container">
                                    <a href="<?php echo esc_url( $content['url'] ); ?>"><i class="fa <?php echo esc_attr( $content['icon'] ); ?>"></i></a>
                                </div><!-- .icon-container -->

                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a></h2>
                                </header>

                                <div class="entry-content">
                                    <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                                </div><!-- .entry-content -->
                            </div><!-- .service-item-wrapper -->
                        </article>
                    <?php endforeach; ?>

                </div><!-- .section-content -->

                <?php 
                if( $options['home_layout'] == 'default-design' || $options['home_layout'] == 'second-design' || $options['home_layout'] == 'third-design' ):

                if ( ! empty( $options['service_btn_title'] ) && ! empty( $options['service_btn_link'] ) ) : ?>
                    <div class="read-more">
                        <a href="<?php echo esc_url( $options['service_btn_link'] ); ?>" class="btn"><?php echo esc_html( $options['service_btn_title'] ); ?></a>
                    </div><!-- .read-more -->
                <?php 
                endif;
                
                endif; ?>
            </div><!-- .wrapper -->
        </div><!-- #our-services -->

    <?php }
endif;