<?php
/**
 * Teachers section
 *
 * This is the template for the content of teachers section
 *
 * @package Theme Palace
 * @subpackage Kidspress Pro
 * @since Kidspress Pro 1.0.0
 */
if ( ! function_exists( 'kidspress_pro_add_teachers_section' ) ) :
    /**
    * Add teachers section
    *
    *@since Kidspress Pro 1.0.0
    */
    function kidspress_pro_add_teachers_section() {
    	$options = kidspress_pro_get_theme_options();
        // Check if teachers is enabled on frontpage
        $teachers_enable = apply_filters( 'kidspress_pro_section_status', true, 'teachers_section_enable' );

        if ( true !== $teachers_enable ) {
            return false;
        }
        // Get teachers section details
        $section_details = array();
        $section_details = apply_filters( 'kidspress_pro_filter_teachers_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render teachers section now.
        kidspress_pro_render_teachers_section( $section_details );
    }
endif;

if ( ! function_exists( 'kidspress_pro_get_teachers_section_details' ) ) :
    /**
    * teachers section details.
    *
    * @since Kidspress Pro 1.0.0
    * @param array $input teachers section details.
    */
    function kidspress_pro_get_teachers_section_details( $input ) {
        $options = kidspress_pro_get_theme_options();

        // Content type.
        $teachers_content_type  = $options['teachers_content_type'];
        $teachers_count = ! empty( $options['teachers_count'] ) ? $options['teachers_count'] : 4;
        
        $content = array();
        switch ( $teachers_content_type ) {
        	
            case 'page':
                $page_ids = array();

                for ( $i = 1; $i <= $teachers_count; $i++ ) {
                    if ( ! empty( $options['teachers_content_page_' . $i] ) ) :
                        $page_ids[] = $options['teachers_content_page_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $teachers_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();

                for ( $i = 1; $i <= $teachers_count; $i++ ) {
                    if ( ! empty( $options['teachers_content_post_' . $i] ) ) :
                        $post_ids[] = $options['teachers_content_post_' . $i];
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $teachers_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['teachers_content_category'] ) ? $options['teachers_content_category'] : '';

                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $teachers_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'tp-team':
                if ( ! class_exists( 'TP_Education' ) ) {
                    return;
                }
                $teachers_ids = array();

                for ( $i = 1; $i <= $teachers_count; $i++ ) {
                    if ( ! empty( $options['teachers_content_teachers_' . $i] ) ) :
                        $teachers_ids[] = $options['teachers_content_teachers_' . $i];
                    endif;
                }

               $args = array(
                    'post_type'         => 'tp-team',
                    'post__in'          => ( array ) $teachers_ids,
                    'posts_per_page'    => absint( $teachers_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    ); 

            break;

            case 'tp-team-category':
                 if ( ! class_exists( 'TP_Education' ) ) {
                    return;
                }

                $cat_id = ! empty( $options['teachers_content_teachers_category'] ) ? $options['teachers_content_teachers_category'] : '';

                $args = array(
                    'post_type'         => 'tp-team',
                    'posts_per_page'    => absint( $teachers_count ),
                    'tax_query'         => array(  
                        array( 
                            'taxonomy'  => 'tp-team-category', 
                            'field'     => 'id', 
                            'terms'     => array( $cat_id ),  
                            ) 
                        ),
                    );  
            break;

            default:
            break;
        }


            // Run The Loop.
            $query = new WP_Query( $args );
            if ( $query->have_posts() ) : 
                $i = 0;
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['url']       = get_the_permalink();
                    $page_post['author']    = kidspress_pro_author();
                    $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'post-thumbnail' ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                    $i++;
                endwhile;
            endif;
            wp_reset_postdata();

            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// teachers section content details.
add_filter( 'kidspress_pro_filter_teachers_section_details', 'kidspress_pro_get_teachers_section_details' );


if ( ! function_exists( 'kidspress_pro_render_teachers_section' ) ) :
  /**
   * Start teachers section
   *
   * @return string teachers content
   * @since Kidspress Pro 1.0.0
   *
   */
   function kidspress_pro_render_teachers_section( $content_details = array() ) {
        $options = kidspress_pro_get_theme_options();
        $teachers_content_type  = $options['teachers_content_type'];
        $column = ! empty( $options['teachers_column'] ) ? $options['teachers_column'] : 'col-4';

        if ( empty( $content_details ) ) {
            return;
        } ?>
        <div id="our-team" class="relative page-section" style="background-image: url('<?php echo $options['teachers_section_bg_image_enable'] ? esc_url(get_template_directory_uri() . '/assets/uploads/blue-cloud-bg.png') : ''; ?>')">
            <div class="wrapper">
                <?php if ( ! empty( $options['teachers_title'] ) || ! empty( $options['teachers_sub_title'] ) ) : ?>
                    <div class="section-header">
                        <?php if ( ! empty( $options['teachers_title'] ) ) : ?>
                            <h2 class="section-title"><?php echo esc_html( $options['teachers_title'] ); ?></h2>
                        <?php endif;

                        if( $options['home_layout'] == 'default-design' || $options['home_layout'] == 'second-design' || $options['home_layout'] == 'third-design' ):

                        if ( ! empty( $options['teachers_sub_title'] ) ) : ?>
                            <p class="section-subtitle"><?php echo esc_html( $options['teachers_sub_title'] ); ?></p>
                        <?php 
                        endif;
                        endif; ?>
                    </div><!-- .section-header -->
                <?php endif; ?>

                <!-- supports col-1, col-2, col-3, col-4 -->
                <div class="section-content clear <?php echo esc_attr($column); ?>">
                     <?php $i =1; foreach ( $content_details as $content ) : ?>
                        <article>
                            <div class="team-item-wrapper">
                                <div class="featured-image" style="background-image: url('<?php echo esc_url( $content['image'] ); ?>');">
                                    <a href="<?php echo esc_url( $content['image'] ); ?>" class="post-thumbnail-link"></a>
                                </div><!-- .featured-image -->

                                <div class="entry-container">
                                    <header class="entry-header">
                                        <h2 class="entry-title"><a href="<?php echo esc_url( $content['url'] ); ?>"><?php echo esc_html( $content['title'] ); ?></a>
                                        </h2>
                                            <?php if ( in_array( $teachers_content_type, array( 'tp-team', 'tp-team-category' ) ) ) : ?>
                                                <p class="position">
                                                   <?php tp_team_designation( $content['id'] ); ?>
                                                </p>
                                            <?php endif; ?>

                                            <?php if( $teachers_content_type == 'post' || $teachers_content_type == 'page' || $teachers_content_type == 'category' ): ?>

                                                <?php if ( ! empty( $options['teacher_position_'.$i ] ) ): ?>

                                                <p class="position">
                                                <?php echo esc_html( $options['teacher_position_'.$i ] ) ; ?>
                                                </p>

                                            <?php endif; ?>

                                            <?php endif; ?>

                                    </header>
                                        <?php if ( in_array( $teachers_content_type, array( 'tp-team', 'tp-team-category' ) ) ) {
                                            do_action( 'tp_team_social_action', $content['id'] ); // Team Social Links 
                                            } ?>
                                </div><!-- .team-item-wrapper -->
                            </div><!-- .entry-container -->
                        </article>
                    <?php $i++; endforeach; ?>

                </div><!-- .section-content -->

               <?php 
               if( $options['home_layout'] == 'default-design' || $options['home_layout'] == 'second-design' || $options['home_layout'] == 'third-design' ):
               if ( ! empty( $options['teachers_btn_title'] ) && ! empty( $options['teachers_btn_link'] ) ) : ?>
                    <div class="read-more">
                        <a href="<?php echo esc_url( $options['teachers_btn_link'] ); ?>" class="btn"><?php echo esc_html( $options['teachers_btn_title'] ); ?></a>
                    </div><!-- .read-more -->
                <?php 
                endif;
                endif; ?>
            </div><!-- .wrapper -->
        </div><!-- #our-team -->

    <?php }
endif;