<?php
/**
 * Testimonial section
 *
 * This is the template for the content of testimonial section
 *
 * @package Theme Palace
 * @subpackage Kidspress Pro
 * @since Kidspress Pro 1.0.0
 */
if ( ! function_exists( 'kidspress_pro_add_testimonial_section' ) ) :
    /**
    * Add testimonial section
    *
    *@since Kidspress Pro 1.0.0
    */
    function kidspress_pro_add_testimonial_section() {
    	$options = kidspress_pro_get_theme_options();
        // Check if testimonial is enabled on frontpage
        $testimonial_enable = apply_filters( 'kidspress_pro_section_status', true, 'testimonial_section_modern' );

        if ( true !== $testimonial_enable ) {
            return false;
        }
        // Get testimonial section details
        $section_details = array();
        $section_details = apply_filters( 'kidspress_pro_filter_testimonial_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render testimonial section now.
        kidspress_pro_render_testimonial_section( $section_details );
    }
endif;

if ( ! function_exists( 'kidspress_pro_get_testimonial_section_details' ) ) :
    /**
    * testimonial section details.
    *
    * @since Kidspress Pro 1.0.0
    * @param array $input testimonial section details.
    */
    function kidspress_pro_get_testimonial_section_details( $input ) {
        $options = kidspress_pro_get_theme_options();

        // Content type.
        $testimonial_content_type  = $options['testimonial_content_type'];
        $testimonial_count = ! empty( $options['testimonial_count'] ) ? $options['testimonial_count'] : 3;
        
        $content = array();
        switch ( $testimonial_content_type ) {
        	
            case 'page':
                $page_ids = array();
                $position = array();

                for ( $i = 1; $i <= $testimonial_count; $i++ ) {
                    if ( ! empty( $options['testimonial_content_page_' . $i] ) ) :
                        $page_ids[] = $options['testimonial_content_page_' . $i];
                        $position[] = ! empty( $options['testimonial_position_' . $i] ) ? $options['testimonial_position_' . $i] : '';
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'page',
                    'post__in'          => ( array ) $page_ids,
                    'posts_per_page'    => absint( $testimonial_count ),
                    'orderby'           => 'post__in',
                    );                    
            break;

            case 'post':
                $post_ids = array();
                $position = array();

                for ( $i = 1; $i <= $testimonial_count; $i++ ) {
                    if ( ! empty( $options['testimonial_content_post_' . $i] ) ) :
                        $post_ids[] = $options['testimonial_content_post_' . $i];
                        $position[] = ! empty( $options['testimonial_position_' . $i] ) ? $options['testimonial_position_' . $i] : '';
                    endif;
                }
                
                $args = array(
                    'post_type'         => 'post',
                    'post__in'          => ( array ) $post_ids,
                    'posts_per_page'    => absint( $testimonial_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'category':
                $cat_id = ! empty( $options['testimonial_content_category'] ) ? $options['testimonial_content_category'] : '';
                $args = array(
                    'post_type'         => 'post',
                    'posts_per_page'    => absint( $testimonial_count ),
                    'cat'               => absint( $cat_id ),
                    'ignore_sticky_posts'   => true,
                    );                    
            break;

            case 'custom':
                for ( $i = 1; $i <= $testimonial_count; $i++ ) {
                    $custom['title']        = ! empty( $options['testimonial_title_' . $i] ) ? $options['testimonial_title_' . $i] : '';
                    $custom['excerpt']      = ! empty( $options['testimonial_description_' . $i] ) ? $options['testimonial_description_' . $i] : '';
                    $custom['image']        = ! empty( $options['testimonial_image_' . $i] ) ? $options['testimonial_image_' . $i] : '';
                    $custom['url']          = ! empty( $options['testimonial_link_' . $i] ) ? $options['testimonial_link_' . $i] : '';
                    $custom['position']     = ! empty( $options['testimonial_position_' . $i] ) ? $options['testimonial_position_' . $i] : '';


                    // Push to the main array.
                    array_push( $content, $custom );
                }
            break;

            case 'tp-testimonial':
                if ( ! class_exists( 'TP_Education' ) ) {
                    return;
                }
                $testimonial_ids = array();

                for ( $i = 1; $i <= $testimonial_count; $i++ ) {
                    if ( ! empty( $options['testimonial_content_testimonial_' . $i] ) ) :
                        $testimonial_ids[] = $options['testimonial_content_testimonial_' . $i];
                    endif;
                }

               $args = array(
                    'post_type'         => 'tp-testimonial',
                    'post__in'          => ( array ) $testimonial_ids,
                    'posts_per_page'    => absint( $testimonial_count ),
                    'orderby'           => 'post__in',
                    'ignore_sticky_posts'   => true,
                    );
            break;


            default:
            break;
        }

        if ( 'custom' !== $testimonial_content_type ) {
            // Run The Loop.
            $query = new WP_Query( $args );
            $i = 0;
            if ( $query->have_posts() ) : 
                while ( $query->have_posts() ) : $query->the_post();
                    $page_post['id']        = get_the_id();
                    $page_post['title']     = get_the_title();
                    $page_post['position']  = ( ! in_array( $testimonial_content_type, array( 'tp-testimonial', 'category' ) ) && ! empty( $position[$i] ) ) ? $position[$i] : '';
                    $page_post['url']       = get_the_permalink();
                    $page_post['excerpt']   = kidspress_pro_trim_content( 20 );
                    $page_post['image']  	= has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id() ) : '';

                    // Push to the main array.
                    array_push( $content, $page_post );
                    $i++;
                endwhile;
            endif;
            wp_reset_postdata();
        }
            
        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// testimonial section content details.
add_filter( 'kidspress_pro_filter_testimonial_section_details', 'kidspress_pro_get_testimonial_section_details' );


if ( ! function_exists( 'kidspress_pro_render_testimonial_section' ) ) :
  /**
   * Start testimonial section
   *
   * @return string testimonial content
   * @since Kidspress Pro 1.0.0
   *
   */
   function kidspress_pro_render_testimonial_section( $content_details = array() ) {
        $options = kidspress_pro_get_theme_options();
        // Content type.
        $testimonial_content_type  = $options['testimonial_content_type'];
        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="testimonial-section" class="relative page-section" style="background-image: url('<?php echo $options['testimonial_section_bg_image_enable'] ? esc_url(get_template_directory_uri() . '/assets/uploads/orange-cloud-bg.png') : ''; ?>')">
                <div class="wrapper">
                    <div class="testimonial-slider">
                        <?php foreach ( $content_details as $content ) : ?>
                            <article>
                                <div class="entry-container">
                                    <div class="quote">
                                        <img src="<?php echo esc_url( get_template_directory_uri() . '/assets/uploads/quote.png' ); ?>" alt="<?php esc_attr_e( 'quote', 'kidspress-pro' ); ?>">
                                    </div><!-- .quote -->

                                    <div class="entry-content">
                                        <p><?php echo wp_kses_post( $content['excerpt'] ); ?></p>
                                    </div><!-- .entry-content -->
                                </div><!-- .entry-container -->
                            </article>
                        <?php endforeach; ?>

                    </div><!-- .testimonial-slider -->

                    <div class="testimonial-nav">
                        <?php foreach ( $content_details as $content ) : ?>
                            <div class="testimonial-item">
                                <div class="featured-image">
                                    <img src="<?php echo esc_url( $content['image'] ); ?>" alt="<?php the_title_attribute() ?>">
                                    <header class="entry-header">
                                        <h2 class="entry-title"><?php echo esc_html( $content['title'] ); ?></h2>
                                         <?php if ( ! in_array( $testimonial_content_type, array( 'tp-testimonial', 'category' ) ) ) : ?>
                                            <p class="position"><?php echo esc_html( $content['position'] ); ?></p>
                                        <?php endif; 

                                        if( 'tp-testimonial' == $testimonial_content_type ) : ?>
                                            <p class="position">
                                                <?php tp_testimonial_designation( $content['id'] ); ?>
                                            </p>
                                        <?php endif; ?>
                                    </header>
                                </div><!-- .featured-image -->
                            </div><!-- .testimonial-item -->
                        <?php endforeach; ?>

                    </div><!-- .slider-nav -->
                </div><!-- .wrapper -->
            </div><!-- #testimonial-section -->
    <?php }
endif;
