<?php
/**
 * Theme Palace basic theme structure hooks
 *
 * This file contains structural hooks.
 *
 * @package Theme Palace
 * @subpackage Kidspress Pro
 * @since Kidspress Pro 1.0.0
 */

$options = kidspress_pro_get_theme_options();


if ( ! function_exists( 'kidspress_pro_doctype' ) ) :
	/**
	 * Doctype Declaration.
	 *
	 * @since Kidspress Pro 1.0.0
	 */
	function kidspress_pro_doctype() {
	?>
		<!DOCTYPE html>
			<html <?php language_attributes(); ?>>
	<?php
	}
endif;

add_action( 'kidspress_pro_doctype', 'kidspress_pro_doctype', 10 );


if ( ! function_exists( 'kidspress_pro_head' ) ) :
	/**
	 * Header Codes
	 *
	 * @since Kidspress Pro 1.0.0
	 *
	 */
	function kidspress_pro_head() {
		?>
		<meta charset="<?php bloginfo( 'charset' ); ?>">
		<meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1">
		<link rel="profile" href="http://gmpg.org/xfn/11">
		<?php if ( is_singular() && pings_open( get_queried_object() ) ) : ?>
			<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>">
		<?php endif;
	}
endif;
add_action( 'kidspress_pro_before_wp_head', 'kidspress_pro_head', 10 );

if ( ! function_exists( 'kidspress_pro_page_start' ) ) :
	/**
	 * Page starts html codes
	 *
	 * @since Kidspress Pro 1.0.0
	 *
	 */
	function kidspress_pro_page_start() {
		?>
		<div id="page" class="site">
			<a class="skip-link screen-reader-text" href="#content"><?php esc_html_e( 'Skip to content', 'kidspress-pro' ); ?></a>
			<div class="menu-overlay"></div>

		<?php
	}
endif;
add_action( 'kidspress_pro_page_start_action', 'kidspress_pro_page_start', 10 );

if ( ! function_exists( 'kidspress_pro_page_end' ) ) :
	/**
	 * Page end html codes
	 *
	 * @since Kidspress Pro 1.0.0
	 *
	 */
	function kidspress_pro_page_end() {
		?>
		</div><!-- #page -->
		<?php
	}
endif;
add_action( 'kidspress_pro_page_end_action', 'kidspress_pro_page_end', 10 );

if ( ! function_exists( 'kidspress_pro_top_menu' ) ) :
	/**
	 * Top menu html codes
	 *
	 * @since Food Restro Pro 1.0.0
	 *
	 */
	function kidspress_pro_top_menu() {
		$options = kidspress_pro_get_theme_options();
		$topbar_phone = ! empty( $options['topbar_phone'] ) ? explode( '|', $options['topbar_phone'] ) : array();
		$topbar_email = ! empty( $options['topbar_email'] ) ? explode( '|', $options['topbar_email'] ) : array();

		if ( ! $options['topbar_section_enable'] )
			return;
		?>

        <div id="top-bar" class="relative">
        	<?php
				echo kidspress_pro_get_svg( array( 'icon' => 'up', 'class' => 'dropdown-icon' ) );
				echo kidspress_pro_get_svg( array( 'icon' => 'down', 'class' => 'dropdown-icon' ) );
			?>

            <div class="wrapper">
                <div class="<?php echo ( (! empty( $topbar_email ) || ! empty( $topbar_phone ) ) && ( $options['topbar_social_enable'] ) ) ? 'col-2' : 'col-1'; ?> clear">
                    <div class="hentry">
                    	<?php if ( ! empty( $topbar_email ) || ! empty( $topbar_phone ) ) : ?>
	                        <ul class="contact-info">
	                            <li>
		                            <?php 
			                        echo kidspress_pro_get_svg( array( 'icon' => 'envelope' ) );
		                            foreach ( $topbar_email as $email ) : ?>
		                            	<a href="<?php echo esc_url( 'mailto:' . $email ); ?>">
		                            	<?php echo esc_html($email ); ?></a>
		                            <?php endforeach; ?>
	                            </li>

	                            <li>
	                            	<?php 
		                            echo kidspress_pro_get_svg( array( 'icon' => 'phone' ) );
	                            	foreach ( $topbar_phone as $phone ) : ?>
	                            		<a href="<?php echo esc_url( 'tel:' . $phone ); ?>">
		                                 	<?php echo esc_html($phone ); ?></a>
	                                <?php endforeach; ?>
	                            </li>
	                        </ul><!-- .contact-info -->
	                    <?php endif; ?>
                    </div><!-- .hentry -->

                    <?php if ( $options['topbar_social_enable'] ) : ?>
	                    <div class="hentry">
	                        <div class="secondary-menu">
	                             <?php 
									wp_nav_menu( array(
										'theme_location' => 'social',
										'menu_class' => 'social-icons',
										'container' => false,
										'echo' => true,
										'fallback_cb' => false,
										'depth' => 1,
										'link_before' => '<span class="screen-reader-text">',
										'link_after' => '</span>',
									) );
								?>
	                        </div><!-- .secondary-menu -->
	                    </div><!-- .hentry -->
	                <?php endif; ?>
                </div><!-- .col-2 -->
            </div><!-- .wrapper -->
        </div><!-- #top-bar -->
		<?php
	}
endif;
add_action( 'kidspress_pro_page_start_action', 'kidspress_pro_top_menu', 10 );


if ( ! function_exists( 'kidspress_pro_header_start' ) ) :
	/**
	 * Header start html codes
	 *
	 * @since Kidspress Pro 1.0.0
	 *
	 */
	function kidspress_pro_header_start() { ?>

		<header id="masthead" class="site-header" role="banner">
			<div class="wrapper">
				
		<?php
	}
endif;
add_action( 'kidspress_pro_header_action', 'kidspress_pro_header_start', 20 );

if ( ! function_exists( 'kidspress_pro_site_branding' ) ) :
	/**
	 * Site branding codes
	 *
	 * @since Kidspress Pro 1.0.0
	 *
	 */
	function kidspress_pro_site_branding() {
		$options  = kidspress_pro_get_theme_options();
		$header_txt_logo_extra = $options['header_txt_logo_extra'];		
		?>
		<?php if ( $options['home_layout'] !== 'fourth-design' ): ?>
		<div class="site-branding">
			<?php if ( in_array( $header_txt_logo_extra, array( 'show-all', 'logo-title', 'logo-tagline' ) )  ) { ?>
				<div class="site-logo">
					<?php the_custom_logo(); ?>
				</div>
			<?php } 
			if ( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title', 'show-all', 'tagline-only', 'logo-tagline' ) ) ) : ?>
				<div id="site-identity">
					<?php
					if( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title' ) )  ) {
						if ( kidspress_pro_is_latest_posts() ) : ?>
							<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
						<?php else : ?>
							<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
						<?php
						endif;
					} 
					if ( in_array( $header_txt_logo_extra, array( 'show-all', 'tagline-only', 'logo-tagline' ) ) ) {
						$description = get_bloginfo( 'description', 'display' );
						if ( $description || is_customize_preview() ) : ?>
							<p class="site-description"><?php echo esc_html( $description ); /* WPCS: xss ok. */ ?></p>
						<?php
						endif; 
					}?>
				</div>
        	<?php endif; ?>
		</div><!-- .site-branding -->
	<?php endif; ?>
	<?php if ( $options['home_layout'] == 'fourth-design' ): ?>

		<div class="site-branding-wrapper">
			<div class="site-branding">
			<?php if ( in_array( $header_txt_logo_extra, array( 'show-all', 'logo-title', 'logo-tagline' ) )  ) { ?>
				<div class="site-logo">
					<?php the_custom_logo(); ?>
				</div>
			<?php } 
			if ( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title', 'show-all', 'tagline-only', 'logo-tagline' ) ) ) : ?>
				<div id="site-identity">
					<?php
					if( in_array( $header_txt_logo_extra, array( 'show-all', 'title-only', 'logo-title' ) )  ) {
						if ( kidspress_pro_is_latest_posts() ) : ?>
							<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
						<?php else : ?>
							<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
						<?php
						endif;
					} 
					if ( in_array( $header_txt_logo_extra, array( 'show-all', 'tagline-only', 'logo-tagline' ) ) ) {
						$description = get_bloginfo( 'description', 'display' );
						if ( $description || is_customize_preview() ) : ?>
							<p class="site-description"><?php echo esc_html( $description ); /* WPCS: xss ok. */ ?></p>
						<?php
						endif; 
					}?>
				</div>
        	<?php endif; ?>
		</div><!-- .site-branding -->

			<?php if ( ! empty( $options['advertisement_image'] ) && ! empty( $options['advertisement_link'] ) ) : ?>
			<div class="site-advertisement">
				<a href="<?php echo esc_url( $options['advertisement_link'] ); ?>"><img src="<?php echo esc_url( $options['advertisement_image'] ); ?>"></a>
			</div><!-- .site-advertisement -->
		<?php endif; ?>
		</div><!-- .site-branding-wrapper -->


	<?php endif; ?>
		<?php
	}
endif;
add_action( 'kidspress_pro_header_action', 'kidspress_pro_site_branding', 30 );

if ( ! function_exists( 'kidspress_pro_site_navigation' ) ) :
	/**
	 * Site navigation codes
	 *
	 * @since Kidspress Pro 1.0.0
	 *
	 */
	function kidspress_pro_site_navigation() {
		$options = kidspress_pro_get_theme_options();
		?>

		 <nav id="site-navigation" class="main-navigation" role="navigation" aria-label="Primary Menu">
		<button class="menu-toggle" aria-controls="primary-menu" aria-expanded="false">
			<?php
			echo kidspress_pro_get_svg( array( 'icon' => 'menu' ) );
			echo kidspress_pro_get_svg( array( 'icon' => 'close' ) );
			?>					
			<span class="menu-label"><?php esc_html_e( 'Menu', 'kidspress-pro' ); ?></span>
		</button>

			<?php 
        		wp_nav_menu( array(
        			'theme_location' => 'primary',
        			'container' => 'div',
        			'menu_class' => 'menu nav-menu',
        			'menu_id' => 'primary-menu',
        			'echo' => true,
        			'fallback_cb' => 'kidspress_pro_menu_fallback_cb',
        		) );
        	?>
		</nav><!-- #site-navigation -->
		<?php
	}
endif;
add_action( 'kidspress_pro_header_action', 'kidspress_pro_site_navigation', 40 );


if ( ! function_exists( 'kidspress_pro_header_end' ) ) :
	/**
	 * Header end html codes
	 *
	 * @since Kidspress Pro 1.0.0
	 *
	 */
	function kidspress_pro_header_end() {
		?>
			</div><!-- .wrapper -->
		</header><!-- #masthead -->
		<?php
	}
endif;

add_action( 'kidspress_pro_header_action', 'kidspress_pro_header_end', 60 );

if ( ! function_exists( 'kidspress_pro_content_start' ) ) :
	/**
	 * Site content codes
	 *
	 * @since Kidspress Pro 1.0.0
	 *
	 */
	function kidspress_pro_content_start() {
		?>
		<div id="content" class="site-content">
		<?php
	}
endif;
add_action( 'kidspress_pro_content_start_action', 'kidspress_pro_content_start', 10 );

if ( ! function_exists( 'kidspress_pro_header_image' ) ) :
	/**
	 * Header Image codes
	 *
	 * @since Kidspress Pro 1.0.0
	 *
	 */
	function kidspress_pro_header_image() {
		if ( kidspress_pro_is_frontpage() )
			return;
		$header_image = get_header_image();
		if ( is_singular() ) :
			$header_image = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : $header_image;
		endif;
		?>

		<div id="page-site-header" class="relative" style="background-image: url('<?php echo esc_url( $header_image ); ?>');">
            <div class="overlay"></div>
            <div class="wrapper">
                <header class="page-header">
                    <h2 class="page-title"><?php kidspress_pro_custom_header_banner_title(); ?></h2>
                </header>

                <?php kidspress_pro_add_breadcrumb(); ?>
            </div><!-- .wrapper -->
        </div><!-- #page-site-header -->
		<?php
	}
endif;
add_action( 'kidspress_pro_header_image_action', 'kidspress_pro_header_image', 10 );

if ( ! function_exists( 'kidspress_pro_add_breadcrumb' ) ) :
	/**
	 * Add breadcrumb.
	 *
	 * @since Kidspress Pro 1.0.0
	 */
	function kidspress_pro_add_breadcrumb() {
		$options = kidspress_pro_get_theme_options();
		// Bail if Breadcrumb disabled.
		$breadcrumb = $options['breadcrumb_enable'];
		if ( false === $breadcrumb ) {
			return;
		}
		
		// Bail if Home Page.
		if ( kidspress_pro_is_frontpage() ) {
			return;
		}

		echo '<div id="breadcrumb-list">';
				/**
				 * kidspress_pro_simple_breadcrumb hook
				 *
				 * @hooked kidspress_pro_simple_breadcrumb -  10
				 *
				 */
				do_action( 'kidspress_pro_simple_breadcrumb' );
		echo '</div><!-- #breadcrumb-list -->';
		return;
	}
endif;
add_action( 'kidspress_pro_header_image_action', 'kidspress_pro_add_breadcrumb', 20 );

if ( ! function_exists( 'kidspress_pro_content_end' ) ) :
	/**
	 * Site content codes
	 *
	 * @since Kidspress Pro 1.0.0
	 *
	 */
	function kidspress_pro_content_end() {
		?>
			<div class="menu-overlay"></div>
		</div><!-- #content -->
		<?php
	}
endif;
add_action( 'kidspress_pro_content_end_action', 'kidspress_pro_content_end', 10 );

if ( ! function_exists( 'kidspress_pro_footer_start' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Kidspress Pro 1.0.0
	 *
	 */
	function kidspress_pro_footer_start() {
		?>
		<footer id="colophon" class="site-footer" role="contentinfo">
		<?php
	}
endif;
add_action( 'kidspress_pro_footer', 'kidspress_pro_footer_start', 10 );

if ( ! function_exists( 'kidspress_pro_footer_site_info' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Kidspress Pro 1.0.0
	 *
	 */
	function kidspress_pro_footer_site_info() {
		$options = kidspress_pro_get_theme_options();
		$search = array( '[the-year]', '[site-link]' );

        $replace = array( date( 'Y' ), '<a href="'. esc_url( home_url( '/' ) ) .'">'. esc_attr( get_bloginfo( 'name', 'display' ) ) . '</a>' );

        $options['copyright_text'] = str_replace( $search, $replace, $options['copyright_text'] );

		$copyright_text = $options['copyright_text']; 
		?>
		<div class="site-info wrapper">
            <span>
            	<?php 
            	echo kidspress_pro_santize_allow_tag( $copyright_text ); 
            	if ( function_exists( 'the_privacy_policy_link' ) ) {
					the_privacy_policy_link( ' | ' );
				}
            	?>
        	</span>
        </div><!-- .site-info -->

		<?php
	}
endif;
add_action( 'kidspress_pro_footer', 'kidspress_pro_footer_site_info', 40 );

if ( ! function_exists( 'kidspress_pro_footer_scroll_to_top' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Kidspress Pro 1.0.0
	 *
	 */
	function kidspress_pro_footer_scroll_to_top() {
		$options  = kidspress_pro_get_theme_options();
		if ( true === $options['scroll_top_visible'] ) : ?>
			<div class="backtotop"><?php echo kidspress_pro_get_svg( array( 'icon' => 'up' ) ); ?></div>
		<?php endif;
	}
endif;
add_action( 'kidspress_pro_footer', 'kidspress_pro_footer_scroll_to_top', 40 );

if ( ! function_exists( 'kidspress_pro_footer_end' ) ) :
	/**
	 * Footer starts
	 *
	 * @since Kidspress Pro 1.0.0
	 *
	 */
	function kidspress_pro_footer_end() {
		?>
		</footer>
		<?php
	}
endif;
add_action( 'kidspress_pro_footer', 'kidspress_pro_footer_end', 100 );

if ( ! function_exists( 'kidspress_pro_loader' ) ) :
	/**
	 * Start div id #loader
	 *
	 * @since Kidspress Pro 1.0.0
	 *
	 */
	function kidspress_pro_loader() {
		$options = kidspress_pro_get_theme_options();
		if ( $options['loader_enable'] ) { ?>

			<div id="loader">
            <div class="loader-container">
            	<?php if ( 'default' == $options['loader_icon'] ) : ?>
	                <div id="preloader">
	                    <span></span>
	                    <span></span>
	                    <span></span>
	                    <span></span>
	                    <span></span>
	                </div>
	            <?php else :
	            	echo kidspress_pro_get_svg( array( 'icon' => esc_attr( $options['loader_icon'] ) ) );
	            endif; ?>
            </div>
        </div><!-- #loader -->
		<?php }
	}
endif;
add_action( 'kidspress_pro_before_header', 'kidspress_pro_loader', 10 );

if ( ! function_exists( 'kidspress_pro_infinite_loader_spinner' ) ) :
	/**
	 *
	 * @since Kidspress Pro 1.0.0
	 *
	 */
	function kidspress_pro_infinite_loader_spinner() { 
		global $post;
		$options = kidspress_pro_get_theme_options();
		if ( $options['pagination_type'] == 'infinite' ) :
			if ( count( ( array ) $post ) > 0) {
				echo '<div class="blog-loader">' . kidspress_pro_get_svg( array( 'icon' => 'spinner-umbrella' ) ) . '</div>';
			}
		endif;
	}
endif;
add_action( 'kidspress_pro_infinite_loader_spinner_action', 'kidspress_pro_infinite_loader_spinner', 10 );
